@@ -81,6 +81,10 @@ common_opts = [
                help="The version of the image service client."),
     cfg.BoolOpt('nova_api_insecure', default=False,
                 help="Allow to perform insecure SSL requests to nova."),
+    cfg.StrOpt('nova_keypair', default=None,
+               help="Name of a Nova keypair to inject into a database "
+                    "instance to enable SSH access. The keypair should be "
+                    "prior created by the cloud operator."),
     cfg.URIOpt('neutron_url', help='URL without the tenant segment.'),
     cfg.StrOpt('neutron_service_type', default='network',
                help='Service type to use when searching catalog.'),
@@ -140,6 +144,10 @@ common_opts = [
                help='Region name for DNSaaS.'),
     cfg.URIOpt('dns_auth_url', default="http://0.0.0.0",
                help='Authentication URL for DNSaaS.'),
+    cfg.StrOpt('dns_user_domain_id', default="default",
+               help='Keystone user domain ID used for auth'),
+    cfg.StrOpt('dns_project_domain_id', default="default",
+               help='Keystone project domain ID used for auth'),
     cfg.StrOpt('dns_domain_name', default="",
                help='Domain name used for adding DNS entries.'),
     cfg.StrOpt('dns_username', default="", secret=True,
@@ -275,7 +283,7 @@ common_opts = [
                 deprecated_name='hostname_require_ipv4'),
     cfg.BoolOpt('trove_security_groups_support', default=True,
                 help='Whether Trove should add Security Groups on create.'),
-    cfg.StrOpt('trove_security_group_name_prefix', default='SecGroup',
+    cfg.StrOpt('trove_security_group_name_prefix', default='trove_sg',
                help='Prefix to use when creating Security Groups.'),
     cfg.StrOpt('trove_security_group_rule_cidr', default='0.0.0.0/0',
                help='CIDR to use when creating Security Group Rules.'),
@@ -413,10 +421,15 @@ common_opts = [
     cfg.ListOpt('expected_filetype_suffixes', default=['json'],
                 help='Filetype endings not to be reattached to an ID '
                      'by the utils method correct_id_with_req.'),
-    cfg.ListOpt('default_neutron_networks', default=[],
+    cfg.ListOpt('management_networks', default=[],
+                deprecated_name='default_neutron_networks',
                 help='List of IDs for management networks which should be '
                      'attached to the instance regardless of what NICs '
-                     'are specified in the create API call.'),
+                     'are specified in the create API call. Currently only '
+                     'one management network is allowed.'),
+    cfg.ListOpt('management_security_groups', default=[],
+                help='List of the security group IDs that are applied on the '
+                     'management port of the database instance.'),
     cfg.IntOpt('max_header_line', default=16384,
                help='Maximum line size of message headers to be accepted. '
                     'max_header_line may need to be increased when using '
@@ -536,7 +549,8 @@ mysql_group = cfg.OptGroup(
     help="Oslo option group designed for MySQL datastore")
 mysql_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', default=["3306"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
@@ -595,7 +609,8 @@ mysql_opts = [
                 deprecated_name='ignore_users',
                 deprecated_group='DEFAULT'),
     cfg.ListOpt('ignore_dbs',
-                default=['mysql', 'information_schema', 'performance_schema'],
+                default=['mysql', 'information_schema', 'performance_schema',
+                         'sys'],
                 help='Databases to exclude when listing databases.',
                 deprecated_name='ignore_dbs',
                 deprecated_group='DEFAULT'),
@@ -619,7 +634,8 @@ percona_group = cfg.OptGroup(
     help="Oslo option group designed for Percona datastore")
 percona_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', default=["3306"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
@@ -707,7 +723,8 @@ pxc_group = cfg.OptGroup(
     help="Oslo option group designed for Percona XtraDB Cluster datastore")
 pxc_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', default=["3306", "4444", "4567", "4568"],
                 item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
@@ -801,7 +818,8 @@ redis_group = cfg.OptGroup(
     help="Oslo option group designed for Redis datastore")
 redis_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', default=["6379", "16379"],
                 item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
@@ -879,7 +897,8 @@ cassandra_group = cfg.OptGroup(
     help="Oslo option group designed for Cassandra datastore")
 cassandra_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', default=["7000", "7001", "7199", "9042", "9160"],
                 item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
@@ -982,7 +1001,8 @@ couchbase_group = cfg.OptGroup(
     help="Oslo option group designed for Couchbase datastore")
 couchbase_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', item_type=ListOfPortsType,
                 default=["8091", "8092", "4369", "11209-11211",
                          "21100-21199"],
@@ -1046,7 +1066,8 @@ mongodb_group = cfg.OptGroup(
     help="Oslo option group designed for MongoDB datastore")
 mongodb_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', default=["2500", "27017", "27019"],
                 item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
@@ -1144,7 +1165,8 @@ postgresql_group = cfg.OptGroup(
     help="Oslo option group for the PostgreSQL datastore.")
 postgresql_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', default=["5432"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
@@ -1219,7 +1241,8 @@ couchdb_group = cfg.OptGroup(
     help="Oslo option group designed for CouchDB datastore")
 couchdb_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports',
                 default=["5984"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
@@ -1281,9 +1304,10 @@ vertica_group = cfg.OptGroup(
     help="Oslo option group designed for Vertica datastore")
 vertica_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', item_type=ListOfPortsType,
-                default=["5433", "5434", "22", "5444", "5450", "4803"],
+                default=["5433", "5434", "5444", "5450", "4803"],
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -1351,7 +1375,8 @@ db2_group = cfg.OptGroup(
     help="Oslo option group designed for DB2 datastore")
 db2_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports',
                 default=["50000"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
@@ -1411,7 +1436,8 @@ mariadb_group = cfg.OptGroup(
     help="Oslo option group designed for MariaDB datastore")
 mariadb_opts = [
     cfg.BoolOpt('icmp', default=False,
-                help='Whether to permit ICMP.'),
+                help='Whether to permit ICMP.',
+                deprecated_for_removal=True),
     cfg.ListOpt('tcp_ports', default=["3306", "4444", "4567", "4568"],
                 item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
@@ -1531,6 +1557,21 @@ rpcapi_cap_opts = [
         help='Set Openstack Release compatibility for conductor services'),
 ]
 
+network_group = cfg.OptGroup(
+    'network',
+    title='Networking options',
+    help="Options related to the trove instance networking."
+)
+network_opts = [
+    cfg.StrOpt(
+        'public_network_id',
+        default=None,
+        help='ID of the Neutron public network to create floating IP for the '
+             'public trove instance. If not given, Trove will try to query '
+             'all the public networks and use the first one in the list.'
+    )
+]
+
 CONF = cfg.CONF
 
 CONF.register_opts(path_opts)
@@ -1551,6 +1592,7 @@ CONF.register_group(couchdb_group)
 CONF.register_group(vertica_group)
 CONF.register_group(db2_group)
 CONF.register_group(mariadb_group)
+CONF.register_group(network_group)
 
 CONF.register_opts(mysql_opts, mysql_group)
 CONF.register_opts(percona_opts, percona_group)
@@ -1564,6 +1606,7 @@ CONF.register_opts(couchdb_opts, couchdb_group)
 CONF.register_opts(vertica_opts, vertica_group)
 CONF.register_opts(db2_opts, db2_group)
 CONF.register_opts(mariadb_opts, mariadb_group)
+CONF.register_opts(network_opts, network_group)
 
 CONF.register_opts(rpcapi_cap_opts, upgrade_levels)
 
