@@ -405,33 +405,16 @@ class BackupUpdateError(TroveError):
     message = _("Unable to update Backup table in database.")
 
 
-class SecurityGroupCreationError(TroveError):
-
-    message = _("Failed to create Security Group.")
-
-
 class SecurityGroupDeletionError(TroveError):
 
     message = _("Failed to delete Security Group.")
 
 
-class SecurityGroupRuleCreationError(TroveError):
-
-    message = _("Failed to create Security Group Rule.")
-
-
 class SecurityGroupRuleDeletionError(TroveError):
 
     message = _("Failed to delete Security Group Rule.")
 
 
-class MalformedSecurityGroupRuleError(TroveError):
-
-    message = _("Error creating security group rules."
-                " Malformed port(s). Port must be an integer."
-                " FromPort = %(from)s greater than ToPort = %(to)s.")
-
-
 class BackupNotCompleteError(TroveError):
 
     message = _("Unable to create instance because backup %(backup_id)s is "
@@ -609,6 +592,10 @@ class NetworkNotFound(TroveError):
     message = _("Network Resource %(uuid)s cannot be found.")
 
 
+class PublicNetworkNotFound(TroveError):
+    message = _("Public network cannot be found.")
+
+
 class ClusterVolumeSizeRequired(TroveError):
     message = _("A volume size is required for each instance in the cluster.")
 
@@ -684,6 +671,11 @@ class LogAccessForbidden(Forbidden):
     message = _("You must be admin to %(action)s log '%(log)s'.")
 
 
+class LogsNotAvailable(Forbidden):
+
+    message = _("Log actions are not supported.")
+
+
 class SlaveOperationNotSupported(TroveError):
 
     message = _("The '%(operation)s' operation is not supported for slaves in "
