@@ -382,7 +382,7 @@ class SetPassword(object):
                       'user_host': self.host,
                       'new_password': self.new_password}
         return ("SET PASSWORD FOR '%(user_name)s'@'%(user_host)s' = "
-                "PASSWORD('%(new_password)s');" % properties)
+                "'%(new_password)s';" % properties)
 
 
 class DropUser(object):
