@@ -19,11 +19,12 @@ from datetime import datetime
 from datetime import timedelta
 import os.path
 import re
-from sqlalchemy import func
+import six
 
 from novaclient import exceptions as nova_exceptions
 from oslo_config.cfg import NoSuchOptError
 from oslo_log import log as logging
+from sqlalchemy import func
 
 from trove.backup.models import Backup
 from trove.common import cfg
@@ -31,9 +32,9 @@ from trove.common import crypto_utils as cu
 from trove.common import exception
 from trove.common.glance_remote import create_glance_client
 from trove.common.i18n import _
-import trove.common.instance as tr_instance
+from trove.common import instance as tr_instance
 from trove.common import neutron
-from trove.common.notification import StartNotification
+from trove.common import notification
 from trove.common.remote import create_cinder_client
 from trove.common.remote import create_dns_client
 from trove.common.remote import create_guest_client
@@ -565,7 +566,7 @@ def load_instance_with_info(cls, context, id, cluster_id=None):
               {'instance_id': id, 'service_status': service_status.status})
     instance = cls(context, db_info, service_status)
     load_guest_info(instance, context, id)
-    load_server_group_info(instance, context, db_info.compute_instance_id)
+    load_server_group_info(instance, context)
     return instance
 
 
@@ -581,8 +582,9 @@ def load_guest_info(instance, context, id):
     return instance
 
 
-def load_server_group_info(instance, context, compute_id):
-    server_group = srv_grp.ServerGroup.load(context, compute_id)
+def load_server_group_info(instance, context):
+    instance_id = instance.slave_of_id if instance.slave_of_id else instance.id
+    server_group = srv_grp.ServerGroup.load(context, instance_id)
     if server_group:
         instance.locality = srv_grp.ServerGroup.get_locality(server_group)
 
@@ -663,9 +665,136 @@ class BaseInstance(SimpleInstance):
                                deltas,
                                _delete_resources)
 
+    def server_status_matches(self, expected_status, server=None):
+        if not server:
+            server = self.server
+
+        return server.status.upper() in (
+            status.upper() for status in expected_status)
+
     def _delete_resources(self, deleted_at):
-        """Implemented in subclass."""
-        pass
+        """Delete the openstack resources related to an instance.
+
+        Deleting the instance should not break or raise exceptions because
+        the end users want their instances to be deleted anyway. Cloud operator
+        should consider the way to clean up orphan resources afterwards, e.g.
+        using the naming convention.
+        """
+        LOG.info("Starting to delete resources for instance %s", self.id)
+
+        old_server = None
+        if self.server_id:
+            # Stop db
+            try:
+                old_server = self.nova_client.servers.get(self.server_id)
+
+                # The server may have already been marked as 'SHUTDOWN'
+                # but check for 'ACTIVE' in case of any race condition
+                # We specifically don't want to attempt to stop db if
+                # the server is in 'ERROR' or 'FAILED" state, as it will
+                # result in a long timeout
+                if self.server_status_matches(['ACTIVE', 'SHUTDOWN'],
+                                              server=self):
+                    LOG.debug("Stopping datastore on instance %s before "
+                              "deleting any resources.", self.id)
+                    self.guest.stop_db()
+            except Exception as e:
+                LOG.warning("Failed to stop the database before attempting "
+                            "to delete trove instance %s, error: %s", self.id,
+                            six.text_type(e))
+
+            # Nova VM
+            if old_server:
+                try:
+                    LOG.info("Deleting server for instance %s", self.id)
+                    self.server.delete()
+                except Exception as e:
+                    LOG.warning("Failed to delete compute server %s",
+                                self.server_id, six.text_type(e))
+
+        # Neutron ports (floating IP)
+        try:
+            ret = self.neutron_client.list_ports(name='trove-%s' % self.id)
+            ports = ret.get("ports", [])
+            for port in ports:
+                LOG.info("Deleting port %s for instance %s", port["id"],
+                         self.id)
+                neutron.delete_port(self.neutron_client, port["id"])
+        except Exception as e:
+            LOG.warning("Failed to delete ports for instance %s, "
+                        "error: %s", self.id, six.text_type(e))
+
+        # Neutron security groups
+        try:
+            name = "%s-%s" % (CONF.trove_security_group_name_prefix, self.id)
+            ret = self.neutron_client.list_security_groups(name=name)
+            sgs = ret.get("security_groups", [])
+            for sg in sgs:
+                LOG.info("Deleting security group %s for instance %s",
+                         sg["id"], self.id)
+                self.neutron_client.delete_security_group(sg["id"])
+        except Exception as e:
+            LOG.warning("Failed to delete security groups for instance %s, "
+                        "error: %s", self.id, six.text_type(e))
+
+        # DNS resources, e.g. Designate
+        try:
+            dns_support = CONF.trove_dns_support
+            if dns_support:
+                dns_api = create_dns_client(self.context)
+                dns_api.delete_instance_entry(instance_id=self.id)
+        except Exception as e:
+            LOG.warning("Failed to delete dns entry of instance %s, error: %s",
+                        self.id, six.text_type(e))
+
+        # Nova server group
+        try:
+            srv_grp.ServerGroup.delete(self.context, self.server_group)
+        except Exception as e:
+            LOG.warning("Failed to delete server group for %s, error: %s",
+                        self.id, six.text_type(e))
+
+        def server_is_finished():
+            try:
+                server = self.nova_client.servers.get(self.server_id)
+                if not self.server_status_matches(['SHUTDOWN', 'ACTIVE'],
+                                                  server=server):
+                    LOG.warning("Server %(vm_id)s entered ERROR status "
+                                "when deleting instance %(instance_id)s!",
+                                {'vm_id': self.server_id,
+                                 'instance_id': self.id})
+                return False
+            except nova_exceptions.NotFound:
+                return True
+
+        if old_server:
+            try:
+                LOG.info("Waiting for compute server %s removal for "
+                         "instance %s", self.server_id, self.id)
+                utils.poll_until(server_is_finished, sleep_time=2,
+                                 time_out=CONF.server_delete_time_out)
+            except exception.PollTimeOut:
+                LOG.warning("Failed to delete instance %(instance_id)s: "
+                            "Timeout deleting compute server %(vm_id)s",
+                            {'instance_id': self.id, 'vm_id': self.server_id})
+
+        # If volume has been resized it must be manually removed
+        try:
+            if self.volume_id:
+                volume = self.volume_client.volumes.get(self.volume_id)
+                if volume.status == "available":
+                    volume.delete()
+        except Exception as e:
+            LOG.warning("Failed to delete volume for instance %s, error: %s",
+                        self.id, six.text_type(e))
+
+        notification.TroveInstanceDelete(
+            instance=self,
+            deleted_at=timeutils.isotime(deleted_at),
+            server=old_server
+        ).notify()
+
+        LOG.info("Finished to delete resources for instance %s", self.id)
 
     def delete_async(self):
         deleted_at = timeutils.utcnow()
@@ -675,8 +804,9 @@ class BaseInstance(SimpleInstance):
                        task_status=InstanceTasks.NONE)
         self.set_servicestatus_deleted()
         self.set_instance_fault_deleted()
-        # Delete associated security group
+
         if CONF.trove_security_groups_support:
+            # Delete associated security group for backward compatibility
             SecurityGroup.delete_for_instance(self.db_info.id, self.context,
                                               self.db_info.region_id)
 
@@ -736,8 +866,8 @@ class BaseInstance(SimpleInstance):
     def server_group(self):
         # The server group could be empty, so we need a flag to cache it
         if not self._server_group_loaded:
-            self._server_group = srv_grp.ServerGroup.load(
-                self.context, self.db_info.compute_instance_id)
+            self._server_group = srv_grp.ServerGroup.load(self.context,
+                                                          self.id)
             self._server_group_loaded = True
         return self._server_group
 
@@ -868,7 +998,7 @@ class Instance(BuiltInstance):
                availability_zone=None, nics=None,
                configuration_id=None, slave_of_id=None, cluster_config=None,
                replica_count=None, volume_type=None, modules=None,
-               locality=None, region_name=None):
+               locality=None, region_name=None, access=None):
 
         region_name = region_name or CONF.os_region_name
 
@@ -1014,9 +1144,11 @@ class Instance(BuiltInstance):
 
         if not nics:
             nics = []
-        if CONF.default_neutron_networks:
-            nics = [{"net-id": net_id}
-                    for net_id in CONF.default_neutron_networks] + nics
+        if CONF.management_networks:
+            # Make sure management network interface is always configured after
+            # user defined instance.
+            nics = nics + [{"net-id": net_id}
+                           for net_id in CONF.management_networks]
         if nics:
             call_args['nics'] = nics
         if cluster_config:
@@ -1050,7 +1182,8 @@ class Instance(BuiltInstance):
             root_password = None
             for instance_index in range(0, instance_count):
                 db_info = DBInstance.create(
-                    name=name, flavor_id=flavor_id, tenant_id=context.tenant,
+                    name=name, flavor_id=flavor_id,
+                    tenant_id=context.project_id,
                     volume_size=volume_size,
                     datastore_version_id=datastore_version.id,
                     task_status=InstanceTasks.BUILDING,
@@ -1060,7 +1193,7 @@ class Instance(BuiltInstance):
                     region_id=region_name)
                 LOG.debug("Tenant %(tenant)s created new Trove instance "
                           "%(db)s in region %(region)s.",
-                          {'tenant': context.tenant, 'db': db_info.id,
+                          {'tenant': context.project_id, 'db': db_info.id,
                            'region': region_name})
 
                 instance_id = db_info.id
@@ -1107,13 +1240,14 @@ class Instance(BuiltInstance):
                 volume_size, backup_id, availability_zone, root_password,
                 nics, overrides, slave_of_id, cluster_config,
                 volume_type=volume_type, modules=module_list,
-                locality=locality)
+                locality=locality, access=access)
 
             return SimpleInstance(context, db_info, service_status,
                                   root_password, locality=locality)
 
-        with StartNotification(context, **call_args):
-            return run_with_quotas(context.tenant, deltas, _create_resources)
+        with notification.StartNotification(context, **call_args):
+            return run_with_quotas(context.project_id, deltas,
+                                   _create_resources)
 
     @classmethod
     def add_instance_modules(cls, context, instance_id, modules):
@@ -1505,7 +1639,7 @@ class Instances(object):
             raise TypeError(_("Argument context not defined."))
         client = create_nova_client(context)
         servers = client.servers.list()
-        query_opts = {'tenant_id': context.tenant,
+        query_opts = {'tenant_id': context.project_id,
                       'deleted': False}
         if not include_clustered:
             query_opts['cluster_id'] = None
@@ -1729,7 +1863,7 @@ def module_instance_count(context, module_id, include_clustered=False):
     if not include_clustered:
         filters.append(DBInstance.cluster_id.is_(None))
     if not context.is_admin:
-        filters.append(DBInstance.tenant_id == context.tenant)
+        filters.append(DBInstance.tenant_id == context.project_id)
     query = query.group_by(module_models.DBInstanceModule.md5)
     query = query.add_columns(*columns)
     query = query.filter(*filters)
