@@ -36,13 +36,11 @@ from trove.instance import models, views
 from trove.module import models as module_models
 from trove.module import views as module_views
 
-
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
 class InstanceController(wsgi.Controller):
-
     """Controller for instance functionality."""
     schemas = apischema.instance.copy()
 
@@ -86,7 +84,7 @@ class InstanceController(wsgi.Controller):
             'restart': self._action_restart,
             'resize': self._action_resize,
             'promote_to_replica_source':
-            self._action_promote_to_replica_source,
+                self._action_promote_to_replica_source,
             'eject_replica_source': self._action_eject_replica_source,
             'reset_status': self._action_reset_status,
         }
@@ -251,8 +249,9 @@ class InstanceController(wsgi.Controller):
         server = models.load_instance_with_info(models.DetailInstance,
                                                 context, id)
         self.authorize_instance_action(context, 'show', server)
-        return wsgi.Result(views.InstanceDetailView(server,
-                                                    req=req).data(), 200)
+        return wsgi.Result(
+            views.InstanceDetailView(server, req=req).data(), 200
+        )
 
     def delete(self, req, tenant_id, id):
         """Delete a single instance."""
@@ -342,7 +341,7 @@ class InstanceController(wsgi.Controller):
             backup_id = None
 
         availability_zone = body['instance'].get('availability_zone')
-        nics = body['instance'].get('nics')
+        nics = body['instance'].get('nics', [])
 
         slave_of_id = body['instance'].get('replica_of',
                                            # also check for older name
@@ -362,7 +361,9 @@ class InstanceController(wsgi.Controller):
                     'Cannot specify locality when adding replicas to existing '
                     'master.')
                 raise exception.BadRequest(message=dupe_locality_msg)
+
         region_name = body['instance'].get('region_name', CONF.os_region_name)
+        access = body['instance'].get('access', None)
 
         instance = models.Instance.create(context, name, flavor_id,
                                           image_id, databases, users,
@@ -374,7 +375,8 @@ class InstanceController(wsgi.Controller):
                                           volume_type=volume_type,
                                           modules=modules,
                                           locality=locality,
-                                          region_name=region_name)
+                                          region_name=region_name,
+                                          access=access)
 
         view = views.InstanceDetailView(instance, req=req)
         return wsgi.Result(view.data(), 200)
@@ -478,12 +480,18 @@ class InstanceController(wsgi.Controller):
         LOG.debug("Default config for instance %(instance_id)s is %(config)s",
                   {'instance_id': id, 'config': config})
         return wsgi.Result(views.DefaultConfigurationView(
-                           config).data(), 200)
+            config).data(), 200)
 
     def guest_log_list(self, req, tenant_id, id):
         """Return all information about all logs for an instance."""
         LOG.debug("Listing logs for tenant %s", tenant_id)
         context = req.environ[wsgi.CONTEXT_KEY]
+
+        try:
+            backup_model.verify_swift_auth_token(context)
+        except exception.SwiftNotFound:
+            raise exception.LogsNotAvailable()
+
         instance = models.Instance.load(context, id)
         if not instance:
             raise exception.NotFound(uuid=id)
@@ -496,6 +504,12 @@ class InstanceController(wsgi.Controller):
         """Processes a guest log."""
         LOG.info("Processing log for tenant %s", tenant_id)
         context = req.environ[wsgi.CONTEXT_KEY]
+
+        try:
+            backup_model.verify_swift_auth_token(context)
+        except exception.SwiftNotFound:
+            raise exception.LogsNotAvailable()
+
         instance = models.Instance.load(context, id)
         if not instance:
             raise exception.NotFound(uuid=id)
