@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
 import os.path
 import time
 import traceback
@@ -19,7 +20,6 @@ import traceback
 from cinderclient import exceptions as cinder_exceptions
 from eventlet import greenthread
 from eventlet.timeout import Timeout
-from novaclient import exceptions as nova_exceptions
 from oslo_log import log as logging
 from oslo_utils import netutils
 from swiftclient.client import ClientException
@@ -38,13 +38,13 @@ from trove.common.exception import BackupCreationError
 from trove.common.exception import GuestError
 from trove.common.exception import GuestTimeout
 from trove.common.exception import InvalidModelError
-from trove.common.exception import MalformedSecurityGroupRuleError
 from trove.common.exception import PollTimeOut
 from trove.common.exception import TroveError
 from trove.common.exception import VolumeCreationFailure
 from trove.common.i18n import _
 from trove.common import instance as rd_instance
 from trove.common.instance import ServiceStatuses
+from trove.common import neutron
 from trove.common.notification import (
     DBaaSInstanceRestart,
     DBaaSInstanceUpgrade,
@@ -52,21 +52,17 @@ from trove.common.notification import (
     StartNotification,
     TroveInstanceCreate,
     TroveInstanceModifyVolume,
-    TroveInstanceModifyFlavor,
-    TroveInstanceDelete)
+    TroveInstanceModifyFlavor)
 import trove.common.remote as remote
 from trove.common.remote import create_cinder_client
 from trove.common.remote import create_dns_client
 from trove.common.remote import create_guest_client
-from trove.common import server_group as srv_grp
 from trove.common.strategies.cluster import strategy
 from trove.common import template
 from trove.common import timeutils
 from trove.common import utils
 from trove.common.utils import try_recover
 from trove.extensions.mysql import models as mysql_models
-from trove.extensions.security_group.models import SecurityGroup
-from trove.extensions.security_group.models import SecurityGroupRule
 from trove.instance import models as inst_models
 from trove.instance.models import BuiltInstance
 from trove.instance.models import DBInstance
@@ -363,7 +359,8 @@ class ClusterTasks(Cluster):
 
         LOG.debug("End rolling restart for id: %s.", cluster_id)
 
-    def rolling_upgrade_cluster(self, context, cluster_id, datastore_version):
+    def rolling_upgrade_cluster(self, context, cluster_id,
+                                datastore_version, ordering_function=None):
         LOG.debug("Begin rolling cluster upgrade for id: %s.", cluster_id)
 
         def _upgrade_cluster_instance(instance):
@@ -383,10 +380,17 @@ class ClusterTasks(Cluster):
         cluster_notification = context.notification
         request_info = cluster_notification.serialize(context)
         try:
+            instances = []
             for db_inst in DBInstance.find_all(cluster_id=cluster_id,
                                                deleted=False).all():
                 instance = BuiltInstanceTasks.load(
                     context, db_inst.id)
+                instances.append(instance)
+
+            if ordering_function is not None:
+                instances.sort(key=ordering_function)
+
+            for instance in instances:
                 _upgrade_cluster_instance(instance)
 
             self.reset_task()
@@ -408,24 +412,10 @@ class ClusterTasks(Cluster):
 
 
 class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
-
-    def _delete_resources(self, deleted_at):
-        LOG.debug("Begin _delete_resources for instance %s", self.id)
-
-        # If volume has "available" status, delete it manually.
-        try:
-            if self.volume_id:
-                volume_client = create_cinder_client(self.context)
-                volume = volume_client.volumes.get(self.volume_id)
-                if volume.status == "available":
-                    LOG.info("Deleting volume %(v)s for instance: %(i)s.",
-                             {'v': self.volume_id, 'i': self.id})
-                    volume.delete()
-        except Exception:
-            LOG.exception("Error deleting volume of instance %(id)s.",
-                          {'id': self.db_info.id})
-
-        LOG.debug("End _delete_resource for instance %s", self.id)
+    """
+    FreshInstanceTasks contains the tasks related an instance that not
+    associated with a compute server.
+    """
 
     def wait_for_instance(self, timeout, flavor):
         # Make sure the service becomes active before sending a usage
@@ -440,10 +430,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             LOG.info("Created instance %s successfully.", self.id)
             TroveInstanceCreate(instance=self,
                                 instance_size=flavor['ram']).notify()
-        except PollTimeOut as ex:
-            LOG.error("Failed to create instance %s. "
-                      "Timeout waiting for instance to become active. "
-                      "No usage create-event was sent.", self.id)
+        except (TroveError, PollTimeOut) as ex:
+            LOG.exception("Failed to create instance %s.", self.id)
             self.update_statuses_on_time_out()
             error_message = "%s" % ex
             error_details = traceback.format_exc()
@@ -458,43 +446,118 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                     self.id, error_message, error_details,
                     skip_delta=CONF.usage_sleep_time + 1)
 
+    def _create_port(self, network, security_groups, is_mgmt=False,
+                     is_public=False):
+        name = 'trove-%s' % self.id
+        type = 'Management' if is_mgmt else 'User'
+        description = '%s port for trove instance %s' % (type, self.id)
+
+        try:
+            port_id = neutron.create_port(
+                self.neutron_client, name,
+                description, network,
+                security_groups,
+                is_public=is_public
+            )
+        except Exception:
+            error = ("Failed to create %s port for instance %s"
+                     % (type, self.id))
+            LOG.exception(error)
+            self.update_db(
+                task_status=inst_models.InstanceTasks.BUILDING_ERROR_PORT
+            )
+            raise TroveError(message=error)
+
+        return port_id
+
+    def _prepare_networks_for_instance(self, datastore_manager, nics,
+                                       access=None):
+        """Prepare the networks for the trove instance.
+
+        the params are all passed from trove-taskmanager.
+
+        Exception is raised if any error happens.
+        """
+        LOG.info("Preparing networks for the instance %s", self.id)
+        security_group = None
+        networks = copy.deepcopy(nics)
+        access = access or {}
+
+        if CONF.trove_security_groups_support:
+            security_group = self._create_secgroup(
+                datastore_manager,
+                access.get('allowed_cidrs', [])
+            )
+            LOG.info(
+                "Security group %s created for instance %s",
+                security_group, self.id
+            )
+
+        # Create management port
+        if CONF.management_networks:
+            port_sgs = [security_group] if security_group else []
+            if len(CONF.management_security_groups) > 0:
+                port_sgs = CONF.management_security_groups
+            # The management network is always the last one
+            networks.pop(-1)
+            port_id = self._create_port(
+                CONF.management_networks[-1],
+                port_sgs,
+                is_mgmt=True
+            )
+            LOG.info("Management port %s created for instance: %s", port_id,
+                     self.id)
+            networks.append({"port-id": port_id})
+
+        # Create port in the user defined network, associate floating IP if
+        # needed
+        if len(networks) > 1 or not CONF.management_networks:
+            network = networks.pop(0).get("net-id")
+            port_sgs = [security_group] if security_group else []
+            port_id = self._create_port(
+                network,
+                port_sgs,
+                is_mgmt=False,
+                is_public=access.get('is_public', False)
+            )
+            LOG.info("User port %s created for instance %s", port_id,
+                     self.id)
+            networks.insert(0, {"port-id": port_id})
+
+        LOG.info(
+            "Finished to prepare networks for the instance %s, networks: %s",
+            self.id, networks
+        )
+        return networks
+
     def create_instance(self, flavor, image_id, databases, users,
                         datastore_manager, packages, volume_size,
                         backup_id, availability_zone, root_password, nics,
                         overrides, cluster_config, snapshot, volume_type,
-                        modules, scheduler_hints):
-        # It is the caller's responsibility to ensure that
-        # FreshInstanceTasks.wait_for_instance is called after
-        # create_instance to ensure that the proper usage event gets sent
+                        modules, scheduler_hints, access=None):
+        """Create trove instance.
 
-        LOG.info("Creating instance %s.", self.id)
-        security_groups = None
-
-        if CONF.trove_security_groups_support:
-            try:
-                security_groups = self._create_secgroup(datastore_manager)
-            except Exception as e:
-                log_fmt = "Error creating security group for instance: %s"
-                exc_fmt = _("Error creating security group for instance: %s")
-                err = inst_models.InstanceTasks.BUILDING_ERROR_SEC_GROUP
-                self._log_and_raise(e, log_fmt, exc_fmt, self.id, err)
-            else:
-                LOG.debug("Successfully created security group for "
-                          "instance: %s", self.id)
+        It is the caller's responsibility to ensure that
+        FreshInstanceTasks.wait_for_instance is called after
+        create_instance to ensure that the proper usage event gets sent
+        """
+        LOG.info(
+            "Creating instance %s, nics: %s, access: %s",
+            self.id, nics, access
+        )
 
+        networks = self._prepare_networks_for_instance(
+            datastore_manager, nics, access=access
+        )
         files = self.get_injected_files(datastore_manager)
         cinder_volume_type = volume_type or CONF.cinder_volume_type
         volume_info = self._create_server_volume(
-            flavor['id'],
-            image_id,
-            security_groups,
-            datastore_manager,
-            volume_size,
-            availability_zone,
-            nics,
-            files,
-            cinder_volume_type,
-            scheduler_hints)
+            flavor['id'], image_id,
+            datastore_manager, volume_size,
+            availability_zone, networks,
+            files, cinder_volume_type,
+            scheduler_hints
+        )
 
         config = self._render_config(flavor)
 
@@ -661,30 +724,27 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         mysql_models.RootHistory.create(self.context, self.id)
 
     def update_statuses_on_time_out(self):
-
         if CONF.update_status_on_fail:
             # Updating service status
             service = InstanceServiceStatus.find_by(instance_id=self.id)
-            service.set_status(ServiceStatuses.
-                               FAILED_TIMEOUT_GUESTAGENT)
+            service.set_status(ServiceStatuses.FAILED_TIMEOUT_GUESTAGENT)
             service.save()
-            LOG.error("Service status: %(status)s\n"
-                      "Service error description: %(desc)s",
-                      {'status': ServiceStatuses.
-                       FAILED_TIMEOUT_GUESTAGENT.api_status,
-                       'desc': ServiceStatuses.
-                       FAILED_TIMEOUT_GUESTAGENT.description})
+            LOG.error(
+                "Service status: %s, service error description: %s",
+                ServiceStatuses.FAILED_TIMEOUT_GUESTAGENT.api_status,
+                ServiceStatuses.FAILED_TIMEOUT_GUESTAGENT.description
+            )
+
             # Updating instance status
             db_info = DBInstance.find_by(id=self.id, deleted=False)
-            db_info.set_task_status(InstanceTasks.
-                                    BUILDING_ERROR_TIMEOUT_GA)
+            db_info.set_task_status(InstanceTasks.BUILDING_ERROR_TIMEOUT_GA)
             db_info.save()
-            LOG.error("Trove instance status: %(action)s\n"
-                      "Trove instance status description: %(text)s",
-                      {'action': InstanceTasks.
-                       BUILDING_ERROR_TIMEOUT_GA.action,
-                       'text': InstanceTasks.
-                       BUILDING_ERROR_TIMEOUT_GA.db_text})
+            LOG.error(
+                "Trove instance status: %s, Trove instance status "
+                "description: %s",
+                InstanceTasks.BUILDING_ERROR_TIMEOUT_GA.action,
+                InstanceTasks.BUILDING_ERROR_TIMEOUT_GA.db_text
+            )
 
     def _service_is_active(self):
         """
@@ -699,6 +759,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         """
         service = InstanceServiceStatus.find_by(instance_id=self.id)
         status = service.get_status()
+        LOG.debug("Service status of instance %(instance)s is %(status)s",
+                  {"instance": self.id, "status": status})
         if (status == rd_instance.ServiceStatuses.RUNNING or
            status == rd_instance.ServiceStatuses.INSTANCE_READY):
                 return True
@@ -711,6 +773,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         c_id = self.db_info.compute_instance_id
         server = self.nova_client.servers.get(c_id)
         server_status = server.status
+        LOG.debug("Server status of instance %s is %s", self.id, server_status)
         if server_status in [InstanceStatus.ERROR,
                              InstanceStatus.FAILED]:
             server_fault_message = 'No fault found'
@@ -718,11 +781,11 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 server_fault_message = server.fault.get('message', 'Unknown')
             except AttributeError:
                 pass
-            server_message = "\nServer error: %s" % server_fault_message
-            raise TroveError(_("Server not active, status: %(status)s "
-                               "%(srv_msg)s") %
-                             {'status': server_status,
-                              'srv_msg': server_message})
+            raise TroveError(
+                _("Server not active, status: %(status)s, fault message: "
+                  "%(srv_msg)s") %
+                {'status': server_status, 'srv_msg': server_fault_message}
+            )
         return False
 
     def _build_sg_rules_mapping(self, rule_ports):
@@ -735,11 +798,9 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                           'to_': str(to_)})
         return final
 
-    def _create_server_volume(self, flavor_id, image_id,
-                              security_groups, datastore_manager,
-                              volume_size, availability_zone,
-                              nics, files, volume_type,
-                              scheduler_hints):
+    def _create_server_volume(self, flavor_id, image_id, datastore_manager,
+                              volume_size, availability_zone, nics, files,
+                              volume_type, scheduler_hints):
         LOG.debug("Begin _create_server_volume for id: %s", self.id)
         server = None
         volume_info = self._build_volume_info(datastore_manager,
@@ -747,11 +808,13 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                                               volume_type=volume_type)
         block_device_mapping_v2 = volume_info['block_device']
         try:
-            server = self._create_server(flavor_id, image_id, security_groups,
-                                         datastore_manager,
-                                         block_device_mapping_v2,
-                                         availability_zone, nics, files,
-                                         scheduler_hints)
+            server = self._create_server(
+                flavor_id, image_id,
+                datastore_manager,
+                block_device_mapping_v2,
+                availability_zone, nics, files,
+                scheduler_hints
+            )
             server_id = server.id
             # Save server ID.
             self.update_db(compute_instance_id=server_id)
@@ -813,7 +876,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         volume_client = create_cinder_client(self.context, self.region_name)
         volume_desc = ("datastore volume for %s" % self.id)
         volume_ref = volume_client.volumes.create(
-            volume_size, name="datastore-%s" % self.id,
+            volume_size, name="trove-%s" % self.id,
             description=volume_desc,
             volume_type=volume_type)
 
@@ -843,7 +906,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         bdm = CONF.block_device_mapping
 
         # use Nova block_device_mapping_v2, referrence:
-        # https://developer.openstack.org/api-ref/compute/#create-server
+        # https://docs.openstack.org/api-ref/compute/#create-server
         # setting the delete_on_terminate instance to true=1
         block_device_v2 = [{
             "uuid": v_ref.id,
@@ -882,22 +945,24 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                 userdata = f.read()
         return userdata
 
-    def _create_server(self, flavor_id, image_id, security_groups,
-                       datastore_manager, block_device_mapping_v2,
-                       availability_zone, nics, files={},
-                       scheduler_hints=None):
+    def _create_server(self, flavor_id, image_id, datastore_manager,
+                       block_device_mapping_v2, availability_zone,
+                       nics, files={}, scheduler_hints=None):
         userdata = self._prepare_userdata(datastore_manager)
         name = self.hostname or self.name
         bdmap_v2 = block_device_mapping_v2
         config_drive = CONF.use_nova_server_config_drive
+        key_name = CONF.nova_keypair
 
         server = self.nova_client.servers.create(
-            name, image_id, flavor_id, files=files, userdata=userdata,
-            security_groups=security_groups, block_device_mapping_v2=bdmap_v2,
-            availability_zone=availability_zone, nics=nics,
-            config_drive=config_drive, scheduler_hints=scheduler_hints)
+            name, image_id, flavor_id, key_name=key_name, nics=nics,
+            block_device_mapping_v2=bdmap_v2,
+            files=files, userdata=userdata,
+            availability_zone=availability_zone,
+            config_drive=config_drive, scheduler_hints=scheduler_hints,
+        )
         LOG.debug("Created new compute instance %(server_id)s "
-                  "for instance %(id)s",
+                  "for database instance %(id)s",
                   {'server_id': server.id, 'id': self.id})
         return server
 
@@ -963,137 +1028,43 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             LOG.debug("%(gt)s: DNS not enabled for instance: %(id)s",
                       {'gt': greenthread.getcurrent(), 'id': self.id})
 
-    def _create_secgroup(self, datastore_manager):
-        security_group = SecurityGroup.create_for_instance(
-            self.id, self.context, self.region_name)
-        tcp_ports = CONF.get(datastore_manager).tcp_ports
-        udp_ports = CONF.get(datastore_manager).udp_ports
-        icmp = CONF.get(datastore_manager).icmp
-        self._create_rules(security_group, tcp_ports, 'tcp')
-        self._create_rules(security_group, udp_ports, 'udp')
-        if icmp:
-            self._create_rules(security_group, None, 'icmp')
-        return [security_group["name"]]
+    def _create_secgroup(self, datastore_manager, allowed_cidrs):
+        name = "%s-%s" % (CONF.trove_security_group_name_prefix, self.id)
 
-    def _create_rules(self, s_group, ports, protocol):
-        err = inst_models.InstanceTasks.BUILDING_ERROR_SEC_GROUP
-        err_msg = _("Failed to create security group rules for instance "
-                    "%(instance_id)s: Invalid port format - "
-                    "FromPort = %(from)s, ToPort = %(to)s")
+        try:
+            sg_id = neutron.create_security_group(
+                self.neutron_client, name, self.id
+            )
 
-        def set_error_and_raise(port_or_range):
-            from_port, to_port = port_or_range
-            self.update_db(task_status=err)
-            msg = err_msg % {'instance_id': self.id, 'from': from_port,
-                             'to': to_port}
-            raise MalformedSecurityGroupRuleError(message=msg)
+            if not allowed_cidrs:
+                allowed_cidrs = [CONF.trove_security_group_rule_cidr]
+            tcp_ports = CONF.get(datastore_manager).tcp_ports
+            udp_ports = CONF.get(datastore_manager).udp_ports
 
-        cidr = CONF.trove_security_group_rule_cidr
+            neutron.create_security_group_rule(
+                self.neutron_client, sg_id, 'tcp', tcp_ports, allowed_cidrs
+            )
+            neutron.create_security_group_rule(
+                self.neutron_client, sg_id, 'udp', udp_ports, allowed_cidrs
+            )
+        except Exception:
+            message = ("Failed to create security group for instance %s"
+                       % self.id)
+            LOG.exception(message)
+            self.update_db(
+                task_status=inst_models.InstanceTasks.BUILDING_ERROR_SEC_GROUP
+            )
+            raise TroveError(message=message)
 
-        if protocol == 'icmp':
-            SecurityGroupRule.create_sec_group_rule(
-                s_group, 'icmp', None, None,
-                cidr, self.context, self.region_name)
-        else:
-            for port_or_range in set(ports):
-                try:
-                    from_, to_ = (None, None)
-                    from_, to_ = port_or_range[0], port_or_range[-1]
-                    SecurityGroupRule.create_sec_group_rule(
-                        s_group, protocol, int(from_), int(to_),
-                        cidr, self.context, self.region_name)
-                except (ValueError, TroveError):
-                    set_error_and_raise([from_, to_])
+        return sg_id
 
 
 class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
     """
-    Performs the various asynchronous instance related tasks.
+    BuiltInstanceTasks contains the tasks related an instance that already
+    associated with a compute server.
     """
 
-    def _delete_resources(self, deleted_at):
-        LOG.debug("Begin _delete_resources for instance %s", self.id)
-        server_id = self.db_info.compute_instance_id
-        old_server = self.nova_client.servers.get(server_id)
-        try:
-            # The server may have already been marked as 'SHUTDOWN'
-            # but check for 'ACTIVE' in case of any race condition
-            # We specifically don't want to attempt to stop db if
-            # the server is in 'ERROR' or 'FAILED" state, as it will
-            # result in a long timeout
-            if self.server_status_matches(['ACTIVE', 'SHUTDOWN'], server=self):
-                LOG.debug("Stopping datastore on instance %s before deleting "
-                          "any resources.", self.id)
-                self.guest.stop_db()
-        except Exception:
-            LOG.exception("Error stopping the datastore before attempting "
-                          "to delete instance id %s.", self.id)
-        try:
-            self.server.delete()
-        except Exception as ex:
-            LOG.exception("Error during delete compute server %s",
-                          self.server.id)
-        try:
-            dns_support = CONF.trove_dns_support
-            LOG.debug("trove dns support = %s", dns_support)
-            if dns_support:
-                dns_api = create_dns_client(self.context)
-                dns_api.delete_instance_entry(instance_id=self.db_info.id)
-        except Exception as ex:
-            LOG.exception("Error during dns entry of instance %(id)s: "
-                          "%(ex)s", {'id': self.db_info.id, 'ex': ex})
-        try:
-            srv_grp.ServerGroup.delete(self.context, self.server_group)
-        except Exception:
-            LOG.exception("Error during delete server group for %s",
-                          self.id)
-
-        # Poll until the server is gone.
-        def server_is_finished():
-            try:
-                server = self.nova_client.servers.get(server_id)
-                if not self.server_status_matches(['SHUTDOWN', 'ACTIVE'],
-                                                  server=server):
-                    LOG.error("Server %(server_id)s entered ERROR status "
-                              "when deleting instance %(instance_id)s!",
-                              {'server_id': server.id, 'instance_id': self.id})
-                return False
-            except nova_exceptions.NotFound:
-                return True
-
-        try:
-            utils.poll_until(server_is_finished, sleep_time=2,
-                             time_out=CONF.server_delete_time_out)
-        except PollTimeOut:
-            LOG.exception("Failed to delete instance %(instance_id)s: "
-                          "Timeout deleting compute server %(server_id)s",
-                          {'instance_id': self.id, 'server_id': server_id})
-
-        # If volume has been resized it must be manually removed in cinder
-        try:
-            if self.volume_id:
-                volume_client = create_cinder_client(self.context,
-                                                     self.region_name)
-                volume = volume_client.volumes.get(self.volume_id)
-                if volume.status == "available":
-                    LOG.info("Deleting volume %(v)s for instance: %(i)s.",
-                             {'v': self.volume_id, 'i': self.id})
-                    volume.delete()
-        except Exception:
-            LOG.exception("Error deleting volume of instance %(id)s.",
-                          {'id': self.db_info.id})
-
-        TroveInstanceDelete(instance=self,
-                            deleted_at=timeutils.isotime(deleted_at),
-                            server=old_server).notify()
-        LOG.debug("End _delete_resources for instance %s", self.id)
-
-    def server_status_matches(self, expected_status, server=None):
-        if not server:
-            server = self.server
-        return server.status.upper() in (
-            status.upper() for status in expected_status)
-
     def resize_volume(self, new_size):
         LOG.info("Resizing volume for instance %(instance_id)s from "
                  "%(old_size)s GB to %(new_size)s GB.",
@@ -1141,7 +1112,7 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                               self.id)
                 raise
 
-        return run_with_quotas(self.context.tenant, {'backups': 1},
+        return run_with_quotas(self.context.project_id, {'backups': 1},
                                _get_replication_snapshot)
 
     def detach_replica(self, master, for_failover=False):
@@ -1249,7 +1220,6 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
 
     def reboot(self):
         try:
-            # Issue a guest stop db call to shutdown the db if running
             LOG.debug("Stopping datastore on instance %s.", self.id)
             try:
                 self.guest.stop_db()
@@ -1258,15 +1228,27 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                 # Also we check guest state before issuing reboot
                 LOG.debug(str(e))
 
-            self._refresh_datastore_status()
-            if not (self.datastore_status_matches(
-                    rd_instance.ServiceStatuses.SHUTDOWN) or
+            # Wait for the mysql stopped.
+            def _datastore_is_offline():
+                self._refresh_datastore_status()
+                return (
                     self.datastore_status_matches(
-                    rd_instance.ServiceStatuses.CRASHED)):
-                # We will bail if db did not get stopped or is blocked
-                LOG.error("Cannot reboot instance. DB status is %s.",
+                        rd_instance.ServiceStatuses.SHUTDOWN) or
+                    self.datastore_status_matches(
+                        rd_instance.ServiceStatuses.CRASHED)
+                )
+
+            try:
+                utils.poll_until(
+                    _datastore_is_offline,
+                    sleep_time=3,
+                    time_out=CONF.reboot_time_out
+                )
+            except exception.PollTimeOut:
+                LOG.error("Cannot reboot instance, DB status is %s",
                           self.datastore_status.status)
                 return
+
             LOG.debug("The guest service status is %s.",
                       self.datastore_status.status)
 
@@ -1281,7 +1263,7 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
 
             utils.poll_until(
                 update_server_info,
-                sleep_time=2,
+                sleep_time=3,
                 time_out=reboot_time_out)
 
             # Set the status to PAUSED. The guest agent will reset the status
@@ -1292,7 +1274,6 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
             LOG.error("Failed to reboot instance %(id)s: %(e)s",
                       {'id': self.id, 'e': str(e)})
         finally:
-            LOG.debug("Rebooting FINALLY %s", self.id)
             self.reset_task_status()
 
     def restart(self):
