@@ -15,16 +15,11 @@
 
 import netaddr
 import os
-import re
 import time
-from time import sleep
 import unittest
 import uuid
 
-
-from proboscis import after_class
 from proboscis.asserts import assert_equal
-from proboscis.asserts import assert_false
 from proboscis.asserts import assert_is_not_none
 from proboscis.asserts import assert_not_equal
 from proboscis.asserts import assert_raises
@@ -34,25 +29,23 @@ from proboscis import before_class
 from proboscis.decorators import time_out
 from proboscis import SkipTest
 from proboscis import test
-import six
 from troveclient.compat import exceptions
 
-from trove.common import exception as rd_exceptions
+from trove.common import cfg
 from trove.common.utils import poll_until
 from trove.datastore import models as datastore_models
 from trove import tests
 from trove.tests.config import CONFIG
 from trove.tests.util.check import AttrCheck
-from trove.tests.util.check import TypeCheck
 from trove.tests.util import create_dbaas_client
-from trove.tests.util import create_nova_client
 from trove.tests.util import dns_checker
-from trove.tests.util import event_simulator
 from trove.tests.util import iso_time
 from trove.tests.util import test_config
 from trove.tests.util.usage import create_usage_verifier
 from trove.tests.util.users import Requirements
 
+CONF = cfg.CONF
+
 FAKE = test_config.values['fake_mode']
 
 GROUP = "dbaas.guest"
@@ -65,7 +58,6 @@ GROUP_USERS = "dbaas.api.users"
 GROUP_ROOT = "dbaas.api.root"
 GROUP_GUEST = "dbaas.guest.start.test"
 GROUP_DATABASES = "dbaas.api.databases"
-GROUP_SECURITY_GROUPS = "dbaas.api.security_groups"
 GROUP_CREATE_INSTANCE_FAILURE = "dbaas.api.failures"
 GROUP_QUOTAS = "dbaas.quotas"
 
@@ -86,14 +78,17 @@ class InstanceTestInfo(object):
         self.dbaas_inactive_datastore_version = None  # The DS inactive id
         self.id = None  # The ID of the instance in the database.
         self.local_id = None
+
+        # The IP address of the database instance for the user.
         self.address = None
+        # The management network IP address.
+        self.mgmt_address = None
+
         self.nics = None  # The dict of type/id for nics used on the instance.
         shared_network = CONFIG.get('shared_network', None)
         if shared_network:
             self.nics = [{'net-id': shared_network}]
         self.initial_result = None  # The initial result from the create call.
-        self.user_ip = None  # The IP address of the instance, given to user.
-        self.infra_ip = None  # The infrastructure network IP address.
         self.result = None  # The instance info returned by the API
         self.nova_client = None  # The instance of novaclient.
         self.volume_client = None  # The instance of the volume client.
@@ -116,28 +111,43 @@ class InstanceTestInfo(object):
                                             'eph.rd-tiny')
         else:
             flavor_name = CONFIG.values.get('instance_flavor_name', 'm1.tiny')
+
         flavors = self.dbaas.find_flavors_by_name(flavor_name)
         assert_equal(len(flavors), 1,
                      "Number of flavors with name '%s' "
                      "found was '%d'." % (flavor_name, len(flavors)))
+
         flavor = flavors[0]
-        assert_true(flavor is not None, "Flavor '%s' not found!" % flavor_name)
         flavor_href = self.dbaas.find_flavor_self_href(flavor)
         assert_true(flavor_href is not None,
                     "Flavor href '%s' not found!" % flavor_name)
+
         return flavor, flavor_href
 
-    def get_address(self):
-        result = self.dbaas_admin.mgmt.instances.show(self.id)
-        if not hasattr(result, 'hostname'):
-            try:
-                return next(str(ip) for ip in result.ip
-                            if netaddr.valid_ipv4(ip))
-            except StopIteration:
-                fail("No IPV4 ip found")
+    def get_address(self, mgmt=False):
+        if mgmt:
+            if self.mgmt_address:
+                return self.mgmt_address
+
+            mgmt_netname = test_config.get("trove_mgmt_network", "trove-mgmt")
+            result = self.dbaas_admin.mgmt.instances.show(self.id)
+            mgmt_interfaces = result.server['addresses'].get(mgmt_netname, [])
+            mgmt_addresses = [str(inf["addr"]) for inf in mgmt_interfaces
+                              if inf["version"] == 4]
+            if len(mgmt_addresses) == 0:
+                fail("No IPV4 ip found for management network.")
+            self.mgmt_address = mgmt_addresses[0]
+            return self.mgmt_address
         else:
-            return [str(ip) for ip in result.server['addresses']
-                    if netaddr.valid_ipv4(ip)]
+            if self.address:
+                return self.address
+
+            result = self.dbaas.instances.get(self.id)
+            addresses = [str(ip) for ip in result.ip if netaddr.valid_ipv4(ip)]
+            if len(addresses) == 0:
+                fail("No IPV4 ip found for database network.")
+            self.address = addresses[0]
+            return self.address
 
     def get_local_id(self):
         mgmt_instance = self.dbaas_admin.management.show(self.id)
@@ -242,17 +252,10 @@ def test_delete_instance_not_found():
       groups=[GROUP, GROUP_QUOTAS],
       runs_after_groups=[tests.PRE_INSTANCES])
 class CreateInstanceQuotaTest(unittest.TestCase):
-
-    def setUp(self):
-        import copy
-
-        self.test_info = copy.deepcopy(instance_info)
-        self.test_info.dbaas_datastore = CONFIG.dbaas_datastore
-
     def tearDown(self):
         quota_dict = {'instances': CONFIG.trove_max_instances_per_tenant,
                       'volumes': CONFIG.trove_max_volumes_per_tenant}
-        dbaas_admin.quota.update(self.test_info.user.tenant_id,
+        dbaas_admin.quota.update(instance_info.user.tenant_id,
                                  quota_dict)
 
     def test_instance_size_too_big(self):
@@ -260,52 +263,48 @@ class CreateInstanceQuotaTest(unittest.TestCase):
                 VOLUME_SUPPORT):
             too_big = CONFIG.trove_max_accepted_volume_size
 
-            self.test_info.volume = {'size': too_big + 1}
-            self.test_info.name = "way_too_large"
             assert_raises(exceptions.OverLimit,
                           dbaas.instances.create,
-                          self.test_info.name,
-                          self.test_info.dbaas_flavor_href,
-                          self.test_info.volume,
+                          "volume_size_too_large",
+                          instance_info.dbaas_flavor_href,
+                          {'size': too_big + 1},
                           nics=instance_info.nics)
 
     def test_update_quota_invalid_resource_should_fail(self):
         quota_dict = {'invalid_resource': 100}
         assert_raises(exceptions.NotFound, dbaas_admin.quota.update,
-                      self.test_info.user.tenant_id, quota_dict)
+                      instance_info.user.tenant_id, quota_dict)
 
     def test_update_quota_volume_should_fail_volume_not_supported(self):
         if VOLUME_SUPPORT:
             raise SkipTest("Volume support needs to be disabled")
         quota_dict = {'volumes': 100}
         assert_raises(exceptions.NotFound, dbaas_admin.quota.update,
-                      self.test_info.user.tenant_id, quota_dict)
+                      instance_info.user.tenant_id, quota_dict)
 
     def test_create_too_many_instances(self):
         instance_quota = 0
         quota_dict = {'instances': instance_quota}
-        new_quotas = dbaas_admin.quota.update(self.test_info.user.tenant_id,
+        new_quotas = dbaas_admin.quota.update(instance_info.user.tenant_id,
                                               quota_dict)
 
-        set_quota = dbaas_admin.quota.show(self.test_info.user.tenant_id)
+        set_quota = dbaas_admin.quota.show(instance_info.user.tenant_id)
         verify_quota = {q.resource: q.limit for q in set_quota}
 
         assert_equal(new_quotas['instances'], quota_dict['instances'])
         assert_equal(0, verify_quota['instances'])
-        self.test_info.volume = None
 
+        volume = None
         if VOLUME_SUPPORT:
             assert_equal(CONFIG.trove_max_volumes_per_tenant,
                          verify_quota['volumes'])
-            self.test_info.volume = {'size':
-                                     CONFIG.get('trove_volume_size', 1)}
+            volume = {'size': CONFIG.get('trove_volume_size', 1)}
 
-        self.test_info.name = "too_many_instances"
         assert_raises(exceptions.OverLimit,
                       dbaas.instances.create,
-                      self.test_info.name,
-                      self.test_info.dbaas_flavor_href,
-                      self.test_info.volume,
+                      "too_many_instances",
+                      instance_info.dbaas_flavor_href,
+                      volume,
                       nics=instance_info.nics)
 
         assert_equal(413, dbaas.last_http_code)
@@ -315,17 +314,15 @@ class CreateInstanceQuotaTest(unittest.TestCase):
             raise SkipTest("Volume support not enabled")
         volume_quota = 3
         quota_dict = {'volumes': volume_quota}
-        self.test_info.volume = {'size': volume_quota + 1}
-        new_quotas = dbaas_admin.quota.update(self.test_info.user.tenant_id,
+        new_quotas = dbaas_admin.quota.update(instance_info.user.tenant_id,
                                               quota_dict)
         assert_equal(volume_quota, new_quotas['volumes'])
 
-        self.test_info.name = "too_large_volume"
         assert_raises(exceptions.OverLimit,
                       dbaas.instances.create,
-                      self.test_info.name,
-                      self.test_info.dbaas_flavor_href,
-                      self.test_info.volume,
+                      "too_large_volume",
+                      instance_info.dbaas_flavor_href,
+                      {'size': volume_quota + 1},
                       nics=instance_info.nics)
 
         assert_equal(413, dbaas.last_http_code)
@@ -378,25 +375,60 @@ class CreateInstanceFail(object):
         self.delete_async(result.id)
 
     @test
-    def test_create_with_bad_nics(self):
-        instance_name = "instance-failure-with-bad-nics"
+    def test_create_with_invalid_net_id(self):
+        instance_name = "instance-failure-with-invalid-net"
         if VOLUME_SUPPORT:
             volume = {'size': CONFIG.get('trove_volume_size', 1)}
         else:
             volume = None
         databases = []
-        bad_nic = [{"port-id": "UNKNOWN", "net-id": "1234",
-                    "v4-fixed-ip": "1.2.3.4"}]
-        result = dbaas.instances.create(instance_name,
-                                        instance_info.dbaas_flavor_href,
-                                        volume, databases, nics=bad_nic)
+        bad_nic = [{"net-id": "1234"}]
 
-        poll_until(self.instance_in_error(result.id))
-        instance = dbaas.instances.get(result.id)
-        assert_equal("ERROR", instance.status)
+        assert_raises(
+            exceptions.BadRequest,
+            dbaas.instances.create,
+            instance_name, instance_info.dbaas_flavor_href,
+            volume, databases, nics=bad_nic
+        )
+        assert_equal(400, dbaas.last_http_code)
 
-        self.delete_async(result.id)
+    @test
+    def test_create_with_multiple_net_id(self):
+        instance_name = "instance_failure_with_multiple_net_id"
+        volume = {'size': CONFIG.get('trove_volume_size', 1)}
+        databases = []
+        multi_nics = [
+            {"net-id": str(uuid.uuid4())},
+            {"net-id": str(uuid.uuid4())}
+        ]
 
+        assert_raises(
+            exceptions.BadRequest,
+            dbaas.instances.create,
+            instance_name, instance_info.dbaas_flavor_href,
+            volume, databases, nics=multi_nics
+        )
+        assert_equal(400, dbaas.last_http_code)
+
+    @test
+    def test_create_with_port_id(self):
+        instance_name = "instance-failure-with-port-id"
+        if VOLUME_SUPPORT:
+            volume = {'size': CONFIG.get('trove_volume_size', 1)}
+        else:
+            volume = None
+        databases = []
+        bad_nic = [{"port-id": "1234"}]
+
+        assert_raises(
+            exceptions.BadRequest,
+            dbaas.instances.create,
+            instance_name, instance_info.dbaas_flavor_href,
+            volume, databases, nics=bad_nic
+        )
+        assert_equal(400, dbaas.last_http_code)
+
+    @test
     def test_create_failure_with_empty_flavor(self):
         instance_name = "instance-failure-with-empty-flavor"
         databases = []
@@ -443,24 +475,13 @@ class CreateInstanceFail(object):
                       nics=instance_info.nics)
         assert_equal(501, dbaas.last_http_code)
 
-    def test_create_failure_with_volume_size_and_disabled_for_datastore(self):
-        instance_name = "instance-failure-volume-size_and_volume_disabled"
-        databases = []
-        datastore = 'redis'
-        assert_equal(CONFIG.get(datastore, 'redis')['volume_support'], False)
-        volume = {'size': 2}
-        assert_raises(exceptions.HTTPNotImplemented, dbaas.instances.create,
-                      instance_name, instance_info.dbaas_flavor_href,
-                      volume, databases, datastore=datastore,
-                      nics=instance_info.nics)
-        assert_equal(501, dbaas.last_http_code)
-
     @test(enabled=EPHEMERAL_SUPPORT)
     def test_create_failure_with_no_ephemeral_flavor(self):
         instance_name = "instance-failure-with-no-ephemeral-flavor"
         databases = []
         flavor_name = CONFIG.values.get('instance_flavor_name', 'm1.tiny')
         flavors = dbaas.find_flavors_by_name(flavor_name)
+
         assert_raises(exceptions.BadRequest, dbaas.instances.create,
                       instance_name, flavors[0].id, None, databases,
                       nics=instance_info.nics)
@@ -788,91 +809,6 @@ class CreateInstanceFlavors(object):
         self._create_with_flavor('custom')
 
 
-@test(depends_on_classes=[InstanceSetup], groups=[GROUP_NEUTRON])
-class CreateInstanceWithNeutron(unittest.TestCase):
-
-    @time_out(TIMEOUT_INSTANCE_CREATE)
-    def setUp(self):
-        if not CONFIG.values.get('neutron_enabled'):
-            raise SkipTest("neutron is not enabled, skipping")
-
-        user = test_config.users.find_user(
-            Requirements(is_admin=False, services=["nova", "trove"]))
-        self.nova_client = create_nova_client(user)
-        self.dbaas_client = create_dbaas_client(user)
-
-        self.result = None
-        self.instance_name = ("TEST_INSTANCE_CREATION_WITH_NICS"
-                              + str(uuid.uuid4()))
-        databases = []
-        self.default_cidr = CONFIG.values.get('shared_network_subnet', None)
-        if VOLUME_SUPPORT:
-            volume = {'size': CONFIG.get('trove_volume_size', 1)}
-        else:
-            volume = None
-
-        self.result = self.dbaas_client.instances.create(
-            self.instance_name,
-            instance_info.dbaas_flavor_href,
-            volume, databases,
-            nics=instance_info.nics)
-        self.instance_id = self.result.id
-
-        def verify_instance_is_active():
-            result = self.dbaas_client.instances.get(self.instance_id)
-            if result.status == "ACTIVE":
-                return True
-            else:
-                assert_equal("BUILD", result.status)
-                return False
-
-        poll_until(verify_instance_is_active)
-
-    def tearDown(self):
-        if self.result.id is not None:
-            self.dbaas_client.instances.delete(self.result.id)
-            while True:
-                try:
-                    self.dbaas_client.instances.get(self.result.id)
-                except exceptions.NotFound:
-                    return True
-                time.sleep(1)
-
-    def check_ip_within_network(self, ip, network):
-        octet_list = str(ip).split(".")
-
-        octets, mask = str(network).split("/")
-        octet_list_ = octets.split(".")
-
-        for i in range(int(mask) / 8):
-            if octet_list[i] != octet_list_[i]:
-                return False
-
-        return True
-
-    def test_ip_within_cidr(self):
-        nova_instance = None
-        for server in self.nova_client.servers.list():
-            if str(server.name) == self.instance_name:
-                nova_instance = server
-                break
-
-        if nova_instance is None:
-            fail("instance created with neutron enabled is not found in nova")
-
-        for address in nova_instance.addresses['private']:
-            ip = address['addr']
-            assert_true(self.check_ip_within_network(ip, self.default_cidr))
-
-        # black list filtered ip not visible via troveclient
-        trove_instance = self.dbaas_client.instances.get(self.result.id)
-
-        for ip in trove_instance.ip:
-            if str(ip).startswith('10.'):
-                assert_true(self.check_ip_within_network(ip, "10.0.0.0/24"))
-                assert_false(self.check_ip_within_network(ip, "10.0.1.0/24"))
-
-
 @test(depends_on_classes=[CreateInstance],
       groups=[GROUP,
               GROUP_START,
@@ -964,122 +900,6 @@ class WaitForGuestInstallationToFinish(object):
                    "the instance at the end of the tests.")
 
 
-@test(depends_on_classes=[WaitForGuestInstallationToFinish],
-      groups=[GROUP, GROUP_SECURITY_GROUPS])
-class SecurityGroupsTest(object):
-
-    @before_class
-    def setUp(self):
-        self.testSecurityGroup = dbaas.security_groups.get(
-            instance_info.id)
-        self.secGroupName = "SecGroup_%s" % instance_info.id
-        self.secGroupDescription = "Security Group for %s" % instance_info.id
-
-    @test
-    def test_created_security_group(self):
-        assert_is_not_none(self.testSecurityGroup)
-        with TypeCheck('SecurityGroup', self.testSecurityGroup) as secGrp:
-            secGrp.has_field('id', six.string_types)
-            secGrp.has_field('name', six.string_types)
-            secGrp.has_field('description', six.string_types)
-            secGrp.has_field('created', six.string_types)
-            secGrp.has_field('updated', six.string_types)
-        assert_equal(self.testSecurityGroup.name, self.secGroupName)
-        assert_equal(self.testSecurityGroup.description,
-                     self.secGroupDescription)
-        assert_equal(self.testSecurityGroup.created,
-                     self.testSecurityGroup.updated)
-
-    @test
-    def test_list_security_group(self):
-        securityGroupList = dbaas.security_groups.list()
-        assert_is_not_none(securityGroupList)
-        securityGroup = [x for x in securityGroupList
-                         if x.name in self.secGroupName]
-        assert_is_not_none(securityGroup)
-
-    @test
-    def test_get_security_group(self):
-        securityGroup = dbaas.security_groups.get(self.testSecurityGroup.id)
-        assert_is_not_none(securityGroup)
-        assert_equal(securityGroup.name, self.secGroupName)
-        assert_equal(securityGroup.description, self.secGroupDescription)
-        assert_equal(securityGroup.instance_id, instance_info.id)
-
-
-@test(depends_on_classes=[SecurityGroupsTest],
-      groups=[GROUP, GROUP_SECURITY_GROUPS])
-class SecurityGroupsRulesTest(object):
-
-    # Security group already have default rule
-    # that is why 'delete'-test is not needed anymore
-
-    @before_class
-    def setUp(self):
-        self.testSecurityGroup = dbaas.security_groups.get(
-            instance_info.id)
-        self.secGroupName = "SecGroup_%s" % instance_info.id
-        self.secGroupDescription = "Security Group for %s" % instance_info.id
-        self.orig_allowable_empty_sleeps = (event_simulator.
-                                            allowable_empty_sleeps)
-        event_simulator.allowable_empty_sleeps = 2
-        self.test_rule_id = None
-
-    @after_class
-    def tearDown(self):
-        (event_simulator.
-         allowable_empty_sleeps) = self.orig_allowable_empty_sleeps
-
-    @test
-    def test_create_security_group_rule(self):
-        # Need to sleep to verify created/updated timestamps
-        time.sleep(1)
-        cidr = "1.2.3.4/16"
-        self.testSecurityGroupRules = (
-            dbaas.security_group_rules.create(
-                group_id=self.testSecurityGroup.id,
-                cidr=cidr))
-        assert_not_equal(len(self.testSecurityGroupRules), 0)
-        assert_is_not_none(self.testSecurityGroupRules)
-        for rule in self.testSecurityGroupRules:
-            assert_is_not_none(rule)
-            assert_equal(rule['security_group_id'],
-                         self.testSecurityGroup.id)
-            assert_is_not_none(rule['id'])
-            assert_equal(rule['cidr'], cidr)
-            assert_equal(rule['from_port'], 3306)
-            assert_equal(rule['to_port'], 3306)
-            assert_is_not_none(rule['created'])
-            self.test_rule_id = rule['id']
-
-        if not CONFIG.fake_mode:
-            group = dbaas.security_groups.get(
-                self.testSecurityGroup.id)
-            assert_not_equal(self.testSecurityGroup.created,
-                             group.updated)
-            assert_not_equal(self.testSecurityGroup.updated,
-                             group.updated)
-
-    @test(depends_on=[test_create_security_group_rule])
-    def test_delete_security_group_rule(self):
-        # Need to sleep to verify created/updated timestamps
-        time.sleep(1)
-        group_before = dbaas.security_groups.get(
-            self.testSecurityGroup.id)
-        dbaas.security_group_rules.delete(self.test_rule_id)
-        assert_equal(204, dbaas.last_http_code)
-
-        if not CONFIG.fake_mode:
-            group = dbaas.security_groups.get(
-                self.testSecurityGroup.id)
-            assert_not_equal(group_before.created,
-                             group.updated)
-            assert_not_equal(group_before.updated,
-                             group.updated)
-            assert_not_equal(self.testSecurityGroup,
-                             group.updated)
-
-
 @test(depends_on_classes=[WaitForGuestInstallationToFinish],
       groups=[GROUP, GROUP_START], enabled=create_new_instance())
 class TestGuestProcess(object):
@@ -1102,12 +922,6 @@ class TestGuestProcess(object):
             assert_true(isinstance(hwinfo.hwinfo['mem_total'], int))
             assert_true(isinstance(hwinfo.hwinfo['num_cpus'], int))
 
-    @test
-    def grab_diagnostics_before_tests(self):
-        if CONFIG.test_mgmt:
-            diagnostics = dbaas_admin.diagnostics.get(instance_info.id)
-            diagnostic_tests_helper(diagnostics)
-
 
 @test(depends_on_classes=[WaitForGuestInstallationToFinish],
       groups=[GROUP, GROUP_TEST, "dbaas.dns"])
@@ -1360,34 +1174,18 @@ class TestCreateNotification(object):
                                              **expected)
 
 
-@test(depends_on_groups=['dbaas.api.instances.actions'],
-      groups=[GROUP, tests.INSTANCES, "dbaas.diagnostics"])
-class CheckDiagnosticsAfterTests(object):
-    """Check the diagnostics after running api commands on an instance."""
-    @test
-    def test_check_diagnostics_on_instance_after_tests(self):
-        diagnostics = dbaas_admin.diagnostics.get(instance_info.id)
-        assert_equal(200, dbaas.last_http_code)
-        diagnostic_tests_helper(diagnostics)
-        msg = "Fat Pete has emerged. size (%s > 30MB)" % diagnostics.vmPeak
-        assert_true(diagnostics.vmPeak < (30 * 1024), msg)
-
-
 @test(depends_on=[WaitForGuestInstallationToFinish],
       depends_on_groups=[GROUP_USERS, GROUP_DATABASES, GROUP_ROOT],
       groups=[GROUP, GROUP_STOP],
       runs_after_groups=[GROUP_START,
-                         GROUP_START_SIMPLE, GROUP_TEST, tests.INSTANCES])
+                         GROUP_START_SIMPLE, GROUP_TEST, tests.INSTANCES],
+      enabled=not do_not_delete_instance())
 class DeleteInstance(object):
     """Delete the created instance."""
 
     @time_out(3 * 60)
     @test
     def test_delete(self):
-        if do_not_delete_instance():
-            CONFIG.get_report().log("TESTS_DO_NOT_DELETE_INSTANCE=True was "
-                                    "specified, skipping delete...")
-            raise SkipTest("TESTS_DO_NOT_DELETE_INSTANCE was specified.")
         global dbaas
         if not hasattr(instance_info, "initial_result"):
             raise SkipTest("Instance was never created, skipping test...")
@@ -1411,27 +1209,10 @@ class DeleteInstance(object):
             fail("A failure occurred when trying to GET instance %s for the %d"
                  " time: %s" % (str(instance_info.id), attempts, str(ex)))
 
-    @time_out(30)
-    @test(enabled=VOLUME_SUPPORT,
-          depends_on=[test_delete])
-    def test_volume_is_deleted(self):
-        try:
-            while True:
-                instance = dbaas.instances.get(instance_info.id)
-                assert_equal(instance.volume['status'], "available")
-                time.sleep(1)
-        except exceptions.NotFound:
-            pass
-        except Exception as ex:
-            fail("Failure: %s" % str(ex))
 
-    # TODO(tim-simpson): make sure that the actual instance, volume,
-    # guest status, and DNS entries are deleted.
-
-
-@test(depends_on=[WaitForGuestInstallationToFinish],
-      runs_after=[DeleteInstance],
-      groups=[GROUP, GROUP_STOP, 'dbaas.usage'])
+@test(depends_on=[DeleteInstance],
+      groups=[GROUP, GROUP_STOP, 'dbaas.usage'],
+      enabled=not do_not_delete_instance())
 class AfterDeleteChecks(object):
 
     @test
@@ -1650,110 +1431,3 @@ class CheckInstance(AttrCheck):
                     slave, allowed_attrs,
                     msg="Replica links not found")
                 self.links(slave['links'])
-
-
-@test(groups=[GROUP])
-class BadInstanceStatusBug(object):
-
-    @before_class()
-    def setUp(self):
-        self.instances = []
-        reqs = Requirements(is_admin=True)
-        self.user = CONFIG.users.find_user(
-            reqs, black_list=[])
-        self.client = create_dbaas_client(self.user)
-        self.mgmt = self.client.management
-
-    @test
-    def test_instance_status_after_double_migrate(self):
-        """
-        This test is to verify that instance status returned is more
-        informative than 'Status is {}'.  There are several ways to
-        replicate this error.  A double migration is just one of them but
-        since this is a known way to recreate that error we will use it
-        here to be sure that the error is fixed.  The actual code lives
-        in trove/instance/models.py in _validate_can_perform_action()
-        """
-        # TODO(imsplitbit): test other instances where this issue could be
-        # replicated.  Resizing a resized instance awaiting confirmation
-        # can be used as another case.  This all boils back to the same
-        # piece of code so I'm not sure if it's relevant or not but could
-        # be done.
-        size = None
-        if VOLUME_SUPPORT:
-            size = {'size': 5}
-
-        result = self.client.instances.create('testbox',
-                                              instance_info.dbaas_flavor_href,
-                                              size,
-                                              nics=instance_info.nics)
-        id = result.id
-        self.instances.append(id)
-
-        def verify_instance_is_active():
-            result = self.client.instances.get(id)
-            print(result.status)
-            return result.status == 'ACTIVE'
-
-        def attempt_migrate():
-            print('attempting migration')
-            try:
-                self.mgmt.migrate(id)
-            except exceptions.UnprocessableEntity:
-                return False
-            return True
-
-        # Timing necessary to make the error occur
-        poll_until(verify_instance_is_active, time_out=120, sleep_time=1)
-
-        try:
-            poll_until(attempt_migrate, time_out=10, sleep_time=1)
-        except rd_exceptions.PollTimeOut:
-            fail('Initial migration timed out')
-
-        try:
-            self.mgmt.migrate(id)
-        except exceptions.UnprocessableEntity as err:
-            assert('status was {}' not in err.message)
-        else:
-            # If we are trying to test what status is returned when an
-            # instance is in a confirm_resize state and another
-            # migration is attempted then we also need to
-            # assert that an exception is raised when running migrate.
-            # If one is not then we aren't able to test what the
-            # returned status is in the exception message.
-            fail('UnprocessableEntity was not thrown')
-
-    @after_class(always_run=True)
-    def tearDown(self):
-        while len(self.instances) > 0:
-            for id in self.instances:
-                try:
-                    self.client.instances.delete(id)
-                    self.instances.remove(id)
-                except exceptions.UnprocessableEntity:
-                    sleep(1.0)
-
-
-def diagnostic_tests_helper(diagnostics):
-    print("diagnostics : %r" % diagnostics._info)
-    allowed_attrs = ['version', 'fdSize', 'vmSize', 'vmHwm', 'vmRss',
-                     'vmPeak', 'threads']
-    CheckInstance(None).contains_allowed_attrs(
-        diagnostics._info, allowed_attrs,
-        msg="Diagnostics")
-    assert_true(isinstance(diagnostics.fdSize, int))
-    assert_true(isinstance(diagnostics.threads, int))
-    assert_true(isinstance(diagnostics.vmHwm, int))
-    assert_true(isinstance(diagnostics.vmPeak, int))
-    assert_true(isinstance(diagnostics.vmRss, int))
-    assert_true(isinstance(diagnostics.vmSize, int))
-    actual_version = diagnostics.version
-    update_test_conf = CONFIG.values.get("guest-update-test", None)
-    if update_test_conf is not None:
-        if actual_version == update_test_conf['next-version']:
-            return  # This is acceptable but may not match the regex.
-    version_pattern = re.compile(r'[a-f0-9]+')
-    msg = "Version %s does not match pattern %s." % (actual_version,
-                                                     version_pattern)
-    assert_true(version_pattern.match(actual_version), msg)
