@@ -22,8 +22,6 @@ from proboscis import before_class
 from proboscis.decorators import time_out
 from proboscis import SkipTest
 from proboscis import test
-from sqlalchemy import exc as sqlalchemy_exc
-from sqlalchemy.sql.expression import text
 from troveclient.compat.exceptions import BadRequest
 from troveclient.compat.exceptions import HTTPNotImplemented
 
@@ -38,7 +36,6 @@ from trove.tests.api.instances import instance_info
 from trove.tests.api.instances import VOLUME_SUPPORT
 from trove.tests.config import CONFIG
 import trove.tests.util as testsutil
-from trove.tests.util.check import Checker
 from trove.tests.util.check import TypeCheck
 from trove.tests.util import LocalSqlClient
 from trove.tests.util.server_connection import create_server_connection
@@ -46,8 +43,9 @@ from trove.tests.util.server_connection import create_server_connection
 GROUP = "dbaas.api.instances.actions"
 GROUP_REBOOT = "dbaas.api.instances.actions.reboot"
 GROUP_RESTART = "dbaas.api.instances.actions.restart"
-GROUP_RESIZE = "dbaas.api.instances.actions.resize.instance"
+GROUP_RESIZE = "dbaas.api.instances.actions.resize"
 GROUP_STOP_MYSQL = "dbaas.api.instances.actions.stop"
+GROUP_UPDATE_GUEST = "dbaas.api.instances.actions.update_guest"
 MYSQL_USERNAME = "test_user"
 MYSQL_PASSWORD = "abcde"
 # stored in test conf
@@ -73,19 +71,27 @@ class MySqlConnection(object):
         self.client = LocalSqlClient(sql_engine, use_flush=False)
 
     def is_connected(self):
+        cmd = "SELECT 1;"
         try:
             with self.client:
-                self.client.execute(text("""SELECT "Hello.";"""))
+                self.client.execute(cmd)
             return True
-        except (sqlalchemy_exc.OperationalError,
-                sqlalchemy_exc.DisconnectionError,
-                sqlalchemy_exc.TimeoutError):
+        except Exception as e:
+            print(
+                "Failed to execute command: %s, error: %s" % (cmd, str(e))
+            )
+            return False
+
+    def execute(self, cmd):
+        try:
+            with self.client:
+                self.client.execute(cmd)
+            return True
+        except Exception as e:
+            print(
+                "Failed to execute command: %s, error: %s" % (cmd, str(e))
+            )
             return False
-        except Exception as ex:
-            print("EX WAS:")
-            print(type(ex))
-            print(ex)
-            raise ex
 
 
 # Use default value from trove.common.cfg, and it could be overridden by
@@ -99,7 +105,6 @@ def get_resize_timeout():
 
 
 TIME_OUT_TIME = get_resize_timeout()
-USER_WAS_DELETED = False
 
 
 class ActionTestBase(object):
@@ -124,6 +129,10 @@ class ActionTestBase(object):
     def instance_address(self):
         return instance_info.get_address()
 
+    @property
+    def instance_mgmt_address(self):
+        return instance_info.get_address(mgmt=True)
+
     @property
     def instance_id(self):
         return instance_info.id
@@ -144,28 +153,34 @@ class ActionTestBase(object):
             time.sleep(5)
 
     def ensure_mysql_is_running(self):
-        """Make sure MySQL is accessible before restarting."""
-        with Checker() as check:
-            if USE_IP:
-                self.connection.connect()
-                check.true(self.connection.is_connected(),
-                           "Able to connect to MySQL.")
-                self.proc_id = self.find_mysql_proc_on_instance()
-                check.true(self.proc_id is not None,
-                           "MySQL process can not be found.")
-            instance = self.instance
-            check.false(instance is None)
-            check.equal(instance.status, "ACTIVE")
+        if USE_IP:
+            self.connection.connect()
+            asserts.assert_true(self.connection.is_connected(),
+                                "Unable to connect to MySQL.")
+
+            self.proc_id = self.find_mysql_proc_on_instance()
+            asserts.assert_is_not_none(self.proc_id,
+                                       "MySQL process can not be found.")
+
+        asserts.assert_is_not_none(self.instance)
+        asserts.assert_equal(self.instance.status, "ACTIVE")
 
     def find_mysql_proc_on_instance(self):
-        server = create_server_connection(self.instance_id)
-        cmd = "ps acux | grep mysqld " \
+        server = create_server_connection(
+            self.instance_id,
+            ip_address=self.instance_mgmt_address
+        )
+        cmd = "sudo ps acux | grep mysqld " \
               "| grep -v mysqld_safe | awk '{print $2}'"
-        stdout, _ = server.execute(cmd)
+
         try:
+            stdout = server.execute(cmd)
             return int(stdout)
         except ValueError:
             return None
+        except Exception as e:
+            asserts.fail("Failed to execute command: %s, error: %s" %
+                         (cmd, str(e)))
 
     def log_current_users(self):
         users = self.dbaas.users.list(self.instance_id)
@@ -208,23 +223,25 @@ class RebootTestBase(ActionTestBase):
     def call_reboot(self):
         raise NotImplementedError()
 
-    def wait_for_broken_connection(self):
-        """Wait until our connection breaks."""
-        if not USE_IP:
-            return
-        if not hasattr(self, "connection"):
-            return
-        poll_until(self.connection.is_connected,
-                   lambda connected: not connected,
-                   time_out=TIME_OUT_TIME)
-
     def wait_for_successful_restart(self):
-        """Wait until status becomes running."""
-        def is_finished_rebooting():
+        """Wait until status becomes running.
+
+        Reboot is an async operation, make sure the instance is rebooting
+        before active.
+        """
+        def _is_rebooting():
             instance = self.instance
             if instance.status == "REBOOT":
+                return True
+            return False
+
+        poll_until(_is_rebooting, time_out=TIME_OUT_TIME)
+
+        def is_finished_rebooting():
+            instance = self.instance
+            asserts.assert_not_equal(instance.status, "ERROR")
+            if instance.status != "ACTIVE":
                 return False
-            asserts.assert_equal("ACTIVE", instance.status)
             return True
 
         poll_until(is_finished_rebooting, time_out=TIME_OUT_TIME)
@@ -238,31 +255,10 @@ class RebootTestBase(ActionTestBase):
 
     def successful_restart(self):
         """Restart MySQL via the REST API successfully."""
-        self.fix_mysql()
         self.call_reboot()
-        self.wait_for_broken_connection()
         self.wait_for_successful_restart()
         self.assert_mysql_proc_is_different()
 
-    def mess_up_mysql(self):
-        """Ruin MySQL's ability to restart."""
-        server = create_server_connection(self.instance_id)
-        cmd = "sudo cp /dev/null /var/lib/mysql/data/ib_logfile%d"
-        instance_info.dbaas_admin.management.stop(self.instance_id)
-        for index in range(2):
-            server.execute(cmd % index)
-
-    def fix_mysql(self):
-        """Fix MySQL's ability to restart."""
-        if not FAKE_MODE:
-            server = create_server_connection(self.instance_id)
-            cmd = "sudo rm /var/lib/mysql/data/ib_logfile%d"
-            # We want to stop mysql so that upstart does not keep trying to
-            # respawn it and block the guest agent from accessing the logs.
-            instance_info.dbaas_admin.management.stop(self.instance_id)
-            for index in range(2):
-                server.execute(cmd % index)
-
     def wait_for_failure_status(self):
         """Wait until status becomes running."""
         def is_finished_rebooting():
@@ -277,19 +273,6 @@ class RebootTestBase(ActionTestBase):
 
         poll_until(is_finished_rebooting, time_out=TIME_OUT_TIME)
 
-    def unsuccessful_restart(self):
-        """Restart MySQL via the REST when it should fail, assert it does."""
-        assert not FAKE_MODE
-        self.mess_up_mysql()
-        self.call_reboot()
-        self.wait_for_broken_connection()
-        self.wait_for_failure_status()
-
-    def restart_normally(self):
-        """Fix iblogs and reboot normally."""
-        self.fix_mysql()
-        self.test_successful_restart()
-
 
 @test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP_RESTART],
       depends_on_groups=[GROUP_START], depends_on=[create_user])
@@ -309,22 +292,14 @@ class RestartTests(RebootTestBase):
         """Make sure MySQL is accessible before restarting."""
         self.ensure_mysql_is_running()
 
-    @test(depends_on=[test_ensure_mysql_is_running], enabled=not FAKE_MODE)
-    def test_unsuccessful_restart(self):
-        """Restart MySQL via the REST when it should fail, assert it does."""
-        if FAKE_MODE:
-            raise SkipTest("Cannot run this in fake mode.")
-        self.unsuccessful_restart()
-
-    @test(depends_on=[test_set_up],
-          runs_after=[test_ensure_mysql_is_running, test_unsuccessful_restart])
+    @test(depends_on=[test_ensure_mysql_is_running])
     def test_successful_restart(self):
         """Restart MySQL via the REST API successfully."""
         self.successful_restart()
 
 
 @test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP_STOP_MYSQL],
-      depends_on_groups=[GROUP_START], depends_on=[create_user])
+      depends_on_groups=[GROUP_RESTART], depends_on=[create_user])
 class StopTests(RebootTestBase):
     """Tests which involve stopping MySQL."""
 
@@ -344,11 +319,10 @@ class StopTests(RebootTestBase):
     def test_stop_mysql(self):
         """Stops MySQL."""
         instance_info.dbaas_admin.management.stop(self.instance_id)
-        self.wait_for_broken_connection()
         self.wait_for_failure_status()
 
     @test(depends_on=[test_stop_mysql])
-    def test_instance_get_shows_volume_info_while_mysql_is_down(self):
+    def test_volume_info_while_mysql_is_down(self):
         """
         Confirms the get call behaves appropriately while an instance is
         down.
@@ -363,15 +337,14 @@ class StopTests(RebootTestBase):
             check.true(isinstance(instance.volume.get('size', None), int))
             check.true(isinstance(instance.volume.get('used', None), float))
 
-    @test(depends_on=[test_set_up],
-          runs_after=[test_instance_get_shows_volume_info_while_mysql_is_down])
+    @test(depends_on=[test_volume_info_while_mysql_is_down])
     def test_successful_restart_when_in_shutdown_state(self):
         """Restart MySQL via the REST API successfully when MySQL is down."""
         self.successful_restart()
 
 
 @test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP_REBOOT],
-      depends_on_groups=[GROUP_START], depends_on=[RestartTests, create_user])
+      depends_on_groups=[GROUP_STOP_MYSQL])
 class RebootTests(RebootTestBase):
     """Tests restarting instance."""
 
@@ -389,14 +362,7 @@ class RebootTests(RebootTestBase):
         """Make sure MySQL is accessible before restarting."""
         self.ensure_mysql_is_running()
 
-    @test(depends_on=[test_ensure_mysql_is_running])
-    def test_unsuccessful_restart(self):
-        """Restart MySQL via the REST when it should fail, assert it does."""
-        if FAKE_MODE:
-            raise SkipTest("Cannot run this in fake mode.")
-        self.unsuccessful_restart()
-
-    @after_class(depends_on=[test_set_up])
+    @after_class(depends_on=[test_ensure_mysql_is_running])
     def test_successful_restart(self):
         """Restart MySQL via the REST API successfully."""
         if FAKE_MODE:
@@ -404,10 +370,8 @@ class RebootTests(RebootTestBase):
         self.successful_restart()
 
 
-@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP,
-              GROUP_RESIZE],
-      depends_on_groups=[GROUP_START], depends_on=[create_user],
-      runs_after=[RebootTests])
+@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP_RESIZE],
+      depends_on_groups=[GROUP_REBOOT])
 class ResizeInstanceTest(ActionTestBase):
 
     """
@@ -438,7 +402,6 @@ class ResizeInstanceTest(ActionTestBase):
             self.connection.connect()
             asserts.assert_true(self.connection.is_connected(),
                                 "Should be able to connect before resize.")
-        self.user_was_deleted = False
 
     @test
     def test_instance_resize_same_size_should_fail(self):
@@ -456,8 +419,6 @@ class ResizeInstanceTest(ActionTestBase):
         poll_until(is_active, time_out=TIME_OUT_TIME)
         asserts.assert_equal(self.instance.status, 'ACTIVE')
 
-        self.get_flavor_href(
-            flavor_id=self.expected_old_flavor_id)
         asserts.assert_raises(HTTPNotImplemented,
                               self.dbaas.instances.resize_instance,
                               self.instance_id, flavors[0].id)
@@ -489,11 +450,6 @@ class ResizeInstanceTest(ActionTestBase):
         flavor = flavors[0]
         self.old_dbaas_flavor = instance_info.dbaas_flavor
         instance_info.dbaas_flavor = flavor
-        asserts.assert_true(flavor is not None,
-                            "Flavor '%s' not found!" % flavor_name)
-        flavor_href = self.dbaas.find_flavor_self_href(flavor)
-        asserts.assert_true(flavor_href is not None,
-                            "Flavor href '%s' not found!" % flavor_name)
         self.expected_new_flavor_id = flavor.id
 
     @test(depends_on=[test_instance_resize_same_size_should_fail])
@@ -534,70 +490,25 @@ class ResizeInstanceTest(ActionTestBase):
         # a resize. The code below is an attempt to catch this while proceeding
         # with the rest of the test (note the use of runs_after).
         if USE_IP:
-            self.connection.connect()
-            if not self.connection.is_connected():
-                # Ok, this is def. a failure, but before we toss up an error
-                # lets recreate to see how far we can get.
-                CONFIG.get_report().log(
-                    "Having to recreate the test_user! Resizing killed it!")
-                self.log_current_users()
+            users = self.dbaas.users.list(self.instance_id)
+            usernames = [user.name for user in users]
+            if MYSQL_USERNAME not in usernames:
                 self.create_user()
-                asserts.fail(
-                    "Somehow, the resize made the test user disappear.")
+                asserts.fail("Resize made the test user disappear.")
 
     @test(depends_on=[test_instance_returns_to_active_after_resize],
           runs_after=[resize_should_not_delete_users])
     def test_make_sure_mysql_is_running_after_resize(self):
         self.ensure_mysql_is_running()
 
-    @test(depends_on=[test_instance_returns_to_active_after_resize],
-          runs_after=[test_make_sure_mysql_is_running_after_resize])
+    @test(depends_on=[test_make_sure_mysql_is_running_after_resize])
     def test_instance_has_new_flavor_after_resize(self):
         actual = self.get_flavor_href(self.instance.flavor['id'])
         expected = self.get_flavor_href(flavor_id=self.expected_new_flavor_id)
         asserts.assert_equal(actual, expected)
 
-    @test(depends_on=[test_instance_has_new_flavor_after_resize])
-    @time_out(TIME_OUT_TIME)
-    def test_resize_down(self):
-        expected_dbaas_flavor = self.expected_dbaas_flavor
 
-        def is_active():
-            return self.instance.status == 'ACTIVE'
-        poll_until(is_active, time_out=TIME_OUT_TIME)
-        asserts.assert_equal(self.instance.status, 'ACTIVE')
-
-        old_flavor_href = self.get_flavor_href(
-            flavor_id=self.expected_old_flavor_id)
-
-        self.dbaas.instances.resize_instance(self.instance_id, old_flavor_href)
-        asserts.assert_equal(202, self.dbaas.last_http_code)
-        self.old_dbaas_flavor = instance_info.dbaas_flavor
-        instance_info.dbaas_flavor = expected_dbaas_flavor
-        self.wait_for_resize()
-        asserts.assert_equal(str(self.instance.flavor['id']),
-                             str(self.expected_old_flavor_id))
-
-    @test(depends_on=[test_resize_down],
-          groups=["dbaas.usage"])
-    def test_resize_instance_down_usage_event_sent(self):
-        expected = self._build_expected_msg()
-        expected['old_instance_size'] = self.old_dbaas_flavor.ram
-        instance_info.consumer.check_message(instance_info.id,
-                                             'trove.instance.modify_flavor',
-                                             **expected)
-
-
-@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP,
-              GROUP + ".resize.instance"],
-      depends_on_groups=[GROUP_START], depends_on=[create_user],
-      runs_after=[RebootTests, ResizeInstanceTest])
-def resize_should_not_delete_users():
-    if USER_WAS_DELETED:
-        asserts.fail("Somehow, the resize made the test user disappear.")
-
-
-@test(runs_after=[ResizeInstanceTest], depends_on=[create_user],
+@test(depends_on=[ResizeInstanceTest],
       groups=[GROUP, tests.INSTANCES, INSTANCE_GROUP, GROUP_RESIZE],
       enabled=VOLUME_SUPPORT)
 class ResizeInstanceVolume(ActionTestBase):
@@ -686,9 +597,8 @@ class ResizeInstanceVolume(ActionTestBase):
 UPDATE_GUEST_CONF = CONFIG.values.get("guest-update-test", None)
 
 
-@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP + ".update_guest"],
-      depends_on=[create_user],
-      depends_on_groups=[GROUP_START])
+@test(groups=[tests.INSTANCES, INSTANCE_GROUP, GROUP, GROUP_UPDATE_GUEST],
+      depends_on_groups=[GROUP_RESIZE])
 class UpdateGuest(object):
 
     def get_version(self):
