@@ -32,13 +32,6 @@ from trove.tests.util.users import Requirements
 GROUP = "dbaas.api.mgmt.ds_versions"
 
 
-@test(groups=[GROUP])
-def mgmt_datastore_version_list_requires_admin_account():
-    """Verify that an admin context is required to call this function."""
-    client = create_client(is_admin=False)
-    assert_raises(exceptions.Unauthorized, client.mgmt_datastore_versions.list)
-
-
 @test(groups=[GROUP])
 class MgmtDataStoreVersion(object):
     """Tests the mgmt datastore version methods."""
@@ -50,13 +43,13 @@ class MgmtDataStoreVersion(object):
         self.user = CONFIG.users.find_user(reqs)
         self.client = create_dbaas_client(self.user)
         self.images = []
-        if test_config.glance_client is not None:
-            glance_user = test_config.users.find_user(
-                Requirements(services=["glance"]))
-            self.glance_client = create_glance_client(glance_user)
-            images = self.glance_client.images.list()
-            for image in images:
-                self.images.append(image.id)
+
+        glance_user = test_config.users.find_user(
+            Requirements(is_admin=True, services=["glance"]))
+        self.glance_client = create_glance_client(glance_user)
+        images = self.glance_client.images.list()
+        for image in images:
+            self.images.append(image.id)
 
     def _find_ds_version_by_name(self, ds_version_name):
         ds_versions = self.client.mgmt_datastore_versions.list()
@@ -68,8 +61,15 @@ class MgmtDataStoreVersion(object):
     def test_mgmt_ds_version_list_original_count(self):
         """Tests the mgmt datastore version list method."""
         self.ds_versions = self.client.mgmt_datastore_versions.list()
-        # By default we create two datastore-versions for mysql
-        assert_equal(2, len(self.ds_versions))
+        # datastore-versions should exist for a functional Trove deployment.
+        assert_true(len(self.ds_versions) > 0)
+
+    @test
+    def mgmt_datastore_version_list_requires_admin_account(self):
+        """Test admin is required to list datastore versions."""
+        client = create_client(is_admin=False)
+        assert_raises(exceptions.Unauthorized,
+                      client.mgmt_datastore_versions.list)
 
     @test(depends_on=[test_mgmt_ds_version_list_original_count])
     def test_mgmt_ds_version_list_fields_present(self):
