@@ -101,7 +101,7 @@ class FakeServer(object):
     next_local_id = 0
 
     def __init__(self, parent, owner, id, name, image_id, flavor_ref,
-                 volumes):
+                 volumes, key_name):
         self.owner = owner  # This is a context.
         self.id = id
         self.parent = parent
@@ -125,6 +125,7 @@ class FakeServer(object):
         setattr(self, 'OS-EXT-AZ:availability_zone', 'nova')
 
         self._info = {'os:volumes': info_vols}
+        self.key_name = key_name
 
     @property
     def addresses(self):
@@ -263,16 +264,16 @@ class FakeServers(object):
         """Can this FakeServers, with its context, see some resource?"""
         server = self.db[id]
         return (self.context.is_admin or
-                server.owner.tenant == self.context.tenant)
+                server.owner.tenant == self.context.project_id)
 
     def create(self, name, image_id, flavor_ref, files=None, userdata=None,
                block_device_mapping_v2=None, security_groups=None,
                availability_zone=None, nics=None, config_drive=False,
-               scheduler_hints=None):
+               scheduler_hints=None, key_name=None):
         id = "FAKE_%s" % uuid.uuid4()
         volumes = self._get_volumes_from_bdm_v2(block_device_mapping_v2)
         server = FakeServer(self, self.context, id, name, image_id, flavor_ref,
-                            volumes)
+                            volumes, key_name)
         self.db[id] = server
         if name.endswith('SERVER_ERROR'):
             raise nova_exceptions.ClientException("Fake server create error.")
@@ -281,12 +282,6 @@ class FakeServers(object):
             raise nova_exceptions.ClientException("The requested availability "
                                                   "zone is not available.")
 
-        if nics:
-            if 'port-id' in nics[0] and nics[0]['port-id'] == "UNKNOWN":
-                raise nova_exceptions.ClientException("The requested "
-                                                      "port-id is not "
-                                                      "available.")
-
         server.schedule_status("ACTIVE", 1)
         LOG.info("FAKE_SERVERS_DB : %s", str(FAKE_SERVERS_DB))
         return server
@@ -438,7 +433,7 @@ class FakeVolumes(object):
         """Can this FakeVolumes, with its context, see some resource?"""
         server = self.db[id]
         return (self.context.is_admin or
-                server.owner.tenant == self.context.tenant)
+                server.owner.tenant == self.context.project_id)
 
     def get(self, id):
         if id not in self.db:
