@@ -36,9 +36,9 @@ from trove.common import timeutils
 from trove.common import utils
 from trove.common.utils import poll_until, build_polling_task
 from trove.tests.config import CONFIG
+from trove.tests import util as test_util
 from trove.tests.util.check import AttrCheck
 from trove.tests.util import create_dbaas_client
-from trove.tests.util import create_nova_client
 from trove.tests.util.users import Requirements
 
 CONF = cfg.CONF
@@ -182,6 +182,7 @@ class InstanceTestInfo(object):
         self.databases = None  # The databases created on the instance.
         self.helper_user = None  # Test helper user if exists.
         self.helper_database = None  # Test helper database if exists.
+        self.admin_user = None
 
 
 class LogOnFail(type):
@@ -259,22 +260,24 @@ class LogOnFail(type):
                     report.log(msg_prefix + "Exception detected, "
                                "but no instance IDs are registered to log.")
 
-                for inst_id in inst_ids:
-                    try:
-                        client.instances.get(inst_id)
-                    except Exception as ex:
-                        report.log(msg_prefix + "Error in instance show "
-                                   "for %s:\n%s" % (inst_id, ex))
-                    try:
-                        log_gen = client.instances.log_generator(
-                            inst_id, 'guest',
-                            publish=True, lines=0, swift=None)
-                        log_contents = "".join([chunk for chunk in log_gen()])
-                        report.log(msg_prefix + "Guest log for %s:\n%s" %
-                                   (inst_id, log_contents))
-                    except Exception as ex:
-                        report.log(msg_prefix + "Error in guest log "
-                                   "retrieval for %s:\n%s" % (inst_id, ex))
+                if CONFIG.instance_log_on_failure:
+                    for inst_id in inst_ids:
+                        try:
+                            client.instances.get(inst_id)
+                        except Exception as ex:
+                            report.log("%s Error in instance show for %s:\n%s"
+                                       % (msg_prefix, inst_id, ex))
+                        try:
+                            log_gen = client.instances.log_generator(
+                                inst_id, 'guest',
+                                publish=True, lines=0, swift=None)
+                            log_contents = "".join(
+                                [chunk for chunk in log_gen()])
+                            report.log("%s Guest log for %s:\n%s" %
+                                       (msg_prefix, inst_id, log_contents))
+                        except Exception as ex:
+                            report.log("%s Error in guest log retrieval for "
+                                       "%s:\n%s" % (msg_prefix, inst_id, ex))
 
                 # Only report on the first error that occurs
                 mcs.reset_inst_ids()
@@ -330,7 +333,10 @@ class TestRunner(object):
         self.instance_info.dbaas_datastore = CONFIG.dbaas_datastore
         self.instance_info.dbaas_datastore_version = (
             CONFIG.dbaas_datastore_version)
-        self.instance_info.user = CONFIG.users.find_user_by_name('alt_demo')
+        self.instance_info.user = CONFIG.users.find_user_by_name("alt_demo")
+        self.instance_info.admin_user = CONFIG.users.find_user(
+            Requirements(is_admin=True)
+        )
         if self.VOLUME_SUPPORT:
             self.instance_info.volume_size = CONFIG.get('trove_volume_size', 1)
             self.instance_info.volume = {
@@ -348,6 +354,7 @@ class TestRunner(object):
         self._admin_client = None
         self._swift_client = None
         self._nova_client = None
+        self._neutron_client = None
         self._test_helper = None
         self._servers = {}
 
@@ -469,21 +476,24 @@ class TestRunner(object):
 
     def _create_admin_client(self):
         """Create a client from an admin user."""
-        requirements = Requirements(is_admin=True, services=["swift"])
+        requirements = Requirements(is_admin=True, services=["trove"])
         admin_user = CONFIG.users.find_user(requirements)
         return create_dbaas_client(admin_user)
 
     @property
     def swift_client(self):
-        return self._create_swift_client()
+        return self._create_swift_client(admin=False)
 
-    def _create_swift_client(self):
-        """Create a swift client from the admin user details."""
-        requirements = Requirements(is_admin=True, services=["swift"])
+    @property
+    def admin_swift_client(self):
+        return self._create_swift_client(admin=True)
+
+    def _create_swift_client(self, admin=True):
+        requirements = Requirements(is_admin=admin, services=["swift"])
         user = CONFIG.users.find_user(requirements)
         os_options = {'region_name': CONFIG.trove_client_region_name}
         return swiftclient.client.Connection(
-            authurl=CONFIG.nova_client['auth_url'],
+            authurl=CONFIG.auth_url,
             user=user.auth_user,
             key=user.auth_key,
             tenant_name=user.tenant,
@@ -492,7 +502,21 @@ class TestRunner(object):
 
     @property
     def nova_client(self):
-        return create_nova_client(self.instance_info.user)
+        if self._nova_client is None:
+            self._nova_client = test_util.create_nova_client(
+                self.instance_info.admin_user
+            )
+
+        return self._nova_client
+
+    @property
+    def neutron_client(self):
+        if self._neutron_client is None:
+            self._neutron_client = test_util.create_neutron_client(
+                self.instance_info.admin_user
+            )
+
+        return self._neutron_client
 
     def register_debug_inst_ids(self, inst_ids):
         """Method to 'register' an instance ID (or list of instance IDs)
@@ -768,7 +792,7 @@ class TestRunner(object):
             self.fail("Found left-over server group: %s" % server_group)
 
     def get_instance(self, instance_id, client=None):
-        client = client or self.auth_client
+        client = client or self.admin_client
         return client.instances.get(instance_id)
 
     def extract_ipv4s(self, ips):
@@ -795,10 +819,8 @@ class TestRunner(object):
         self.assert_equal(
             1, len(flavors),
             "Unexpected number of flavors with name '%s' found." % flavor_name)
-        flavor = flavors[0]
-        self.assert_is_not_none(flavor, "Flavor '%s' not found." % flavor_name)
 
-        return flavor
+        return flavors[0]
 
     def get_instance_flavor(self, fault_num=None):
         name_format = 'instance%s%s_flavor_name'
