@@ -61,7 +61,7 @@ class SimpleInstanceTest(trove_testtools.TestCase):
         super(SimpleInstanceTest, self).tearDown()
         CONF.network_label_regex = self.orig_conf
         CONF.ip_start = None
-        CONF.default_neutron_networks = []
+        CONF.management_networks = []
         CONF.ip_regex = self.orig_ip_regex
         CONF.black_list_regex = self.orig_black_list_regex
 
@@ -116,7 +116,7 @@ class SimpleInstanceTest(trove_testtools.TestCase):
     @patch('trove.common.remote.create_neutron_client')
     def test_filter_management_ip_addresses(self, mock_neutron_client):
         CONF.network_label_regex = ''
-        CONF.default_neutron_networks = ['fake-net-id']
+        CONF.management_networks = ['fake-net-id']
 
         neutron_client = Mock()
         neutron_client.show_network.return_value = {
@@ -207,8 +207,6 @@ class CreateInstanceTest(trove_testtools.TestCase):
             datastore_version_id=self.datastore_version.id,
             deleted=False
         )
-        self.backup.size = 1.1
-        self.backup.save()
         self.backup_id = self.backup.id
         self.orig_client = models.create_nova_client
         models.create_nova_client = nova.fake_create_nova_client
@@ -243,6 +241,8 @@ class CreateInstanceTest(trove_testtools.TestCase):
         super(CreateInstanceTest, self).tearDown()
 
     def test_exception_on_invalid_backup_size(self):
+        self.backup.size = 1.1
+        self.backup.save()
         self.assertEqual(self.backup.id, self.backup_id)
         exc = self.assertRaises(
             exception.BackupTooLarge, models.Instance.create,
